;;; thing-at-point-utils.el  --- more thing-at-point edit functions

;; Version: 1.5

;; Copyright (C) 2006, 2007 Andreas Roehler

;; Author: Andreas Roehler <andreas.roehler@easy-emacs.de>

;; Keywords: convenience

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Information is given with thingatpt-utils-base.el

(require 'thingatpt-utils-base)



;;;###autoload
(defun list-atpt (&optional arg ispec) 
  "Returns list at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-list-atpt (&optional arg ispec) 
  "Returns borders of list at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun list-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-list-atpt (&optional arg ispec) 
  " list at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "list" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "list" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun list-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-list-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class list at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-list-atpt () 
  "Makes a copy of symbol or char-class list at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'list))

;;;###autoload
(defun separate-list-atpt (&optional arg ispec) 
  "Separates list at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-list-atpt (&optional arg ispec) 
  "Comments list at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-list-atpt (&optional arg ispec) 
  "Doublequotes list at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'doublequote arg ispec))

;;;###autoload
(defun singlequote-list-atpt (&optional arg ispec) 
  "Singlequotes list at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'singlequote arg ispec))

;;;###autoload
(defun parenthese-list-atpt (&optional arg ispec) 
  "Parentizes list at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'list 'parentize arg ispec))

;;;###autoload
(defun brace-list-atpt (&optional arg ispec) 
  "Braces list at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'brace arg ispec))

;;;###autoload
(defun bracket-list-atpt (&optional arg ispec) 
  "Brackets list after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'bracket arg ispec))

;;;###autoload
(defun kill-list-atpt ()
  "Kills list at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'list))

;;;###autoload
(defun mark-list-atpt ()
  "Marks list at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'list))

;;;###autoload
(defun forward-list-atpt (&optional arg ispec) 
  "Moves forward over list at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-list-atpt (&optional arg ispec) 
  "Moves backward over list before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-list-atpt (&optional arg) 
  "Transposes list with list before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-list-atpt arg))
   ;;   (thatpt-transpose 'list arg))
   

;;;###autoload
(defun symbol-atpt (&optional arg ispec) 
  "Returns symbol at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-symbol-atpt (&optional arg ispec) 
  "Returns borders of symbol at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun symbol-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-symbol-atpt (&optional arg ispec) 
  " symbol at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "symbol" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "symbol" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun symbol-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-symbol-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-symbol-atpt () 
  "Makes a copy of symbol or char-class symbol at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'symbol))

;;;###autoload
(defun separate-symbol-atpt (&optional arg ispec) 
  "Separates symbol at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-symbol-atpt (&optional arg ispec) 
  "Comments symbol at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-symbol-atpt (&optional arg ispec) 
  "Doublequotes symbol at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'doublequote arg ispec))

;;;###autoload
(defun singlequote-symbol-atpt (&optional arg ispec) 
  "Singlequotes symbol at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'singlequote arg ispec))

;;;###autoload
(defun parenthese-symbol-atpt (&optional arg ispec) 
  "Parentizes symbol at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'symbol 'parentize arg ispec))

;;;###autoload
(defun brace-symbol-atpt (&optional arg ispec) 
  "Braces symbol at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'brace arg ispec))

;;;###autoload
(defun bracket-symbol-atpt (&optional arg ispec) 
  "Brackets symbol after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'bracket arg ispec))

;;;###autoload
(defun kill-symbol-atpt ()
  "Kills symbol at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'symbol))

;;;###autoload
(defun mark-symbol-atpt ()
  "Marks symbol at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'symbol))

;;;###autoload
(defun forward-symbol-atpt (&optional arg ispec) 
  "Moves forward over symbol at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-symbol-atpt (&optional arg ispec) 
  "Moves backward over symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-symbol-atpt (&optional arg) 
  "Transposes symbol with symbol before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-symbol-atpt arg))
   ;;   (thatpt-transpose 'symbol arg))
   

;;;###autoload
(defun word-atpt (&optional arg ispec) 
  "Returns word at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-word-atpt (&optional arg ispec) 
  "Returns borders of word at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun word-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-word-atpt (&optional arg ispec) 
  " word at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "word" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "word" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun word-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-word-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class word at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-word-atpt () 
  "Makes a copy of symbol or char-class word at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'word))

;;;###autoload
(defun separate-word-atpt (&optional arg ispec) 
  "Separates word at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-word-atpt (&optional arg ispec) 
  "Comments word at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-word-atpt (&optional arg ispec) 
  "Doublequotes word at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'doublequote arg ispec))

;;;###autoload
(defun singlequote-word-atpt (&optional arg ispec) 
  "Singlequotes word at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'singlequote arg ispec))

;;;###autoload
(defun parenthese-word-atpt (&optional arg ispec) 
  "Parentizes word at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'word 'parentize arg ispec))

;;;###autoload
(defun brace-word-atpt (&optional arg ispec) 
  "Braces word at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'brace arg ispec))

;;;###autoload
(defun bracket-word-atpt (&optional arg ispec) 
  "Brackets word after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'bracket arg ispec))

;;;###autoload
(defun kill-word-atpt ()
  "Kills word at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'word))

;;;###autoload
(defun mark-word-atpt ()
  "Marks word at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'word))

;;;###autoload
(defun forward-word-atpt (&optional arg ispec) 
  "Moves forward over word at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-word-atpt (&optional arg ispec) 
  "Moves backward over word before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-word-atpt (&optional arg) 
  "Transposes word with word before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-word-atpt arg))
   ;;   (thatpt-transpose 'word arg))
   

;;;###autoload
(defun sexp-atpt (&optional arg ispec) 
  "Returns sexp at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-sexp-atpt (&optional arg ispec) 
  "Returns borders of sexp at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun sexp-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-sexp-atpt (&optional arg ispec) 
  " sexp at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "sexp" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "sexp" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun sexp-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-sexp-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-sexp-atpt () 
  "Makes a copy of symbol or char-class sexp at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'sexp))

;;;###autoload
(defun separate-sexp-atpt (&optional arg ispec) 
  "Separates sexp at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-sexp-atpt (&optional arg ispec) 
  "Comments sexp at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-sexp-atpt (&optional arg ispec) 
  "Doublequotes sexp at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'doublequote arg ispec))

;;;###autoload
(defun singlequote-sexp-atpt (&optional arg ispec) 
  "Singlequotes sexp at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'singlequote arg ispec))

;;;###autoload
(defun parenthese-sexp-atpt (&optional arg ispec) 
  "Parentizes sexp at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'sexp 'parentize arg ispec))

;;;###autoload
(defun brace-sexp-atpt (&optional arg ispec) 
  "Braces sexp at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'brace arg ispec))

;;;###autoload
(defun bracket-sexp-atpt (&optional arg ispec) 
  "Brackets sexp after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'bracket arg ispec))

;;;###autoload
(defun kill-sexp-atpt ()
  "Kills sexp at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'sexp))

;;;###autoload
(defun mark-sexp-atpt ()
  "Marks sexp at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'sexp))

;;;###autoload
(defun forward-sexp-atpt (&optional arg ispec) 
  "Moves forward over sexp at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-sexp-atpt (&optional arg ispec) 
  "Moves backward over sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-sexp-atpt (&optional arg) 
  "Transposes sexp with sexp before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-sexp-atpt arg))
   ;;   (thatpt-transpose 'sexp arg))
   

;;;###autoload
(defun paragraph-atpt (&optional arg ispec) 
  "Returns paragraph at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-paragraph-atpt (&optional arg ispec) 
  "Returns borders of paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun paragraph-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-paragraph-atpt (&optional arg ispec) 
  " paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "paragraph" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "paragraph" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun paragraph-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-paragraph-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-paragraph-atpt () 
  "Makes a copy of symbol or char-class paragraph at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'paragraph))

;;;###autoload
(defun separate-paragraph-atpt (&optional arg ispec) 
  "Separates paragraph at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-paragraph-atpt (&optional arg ispec) 
  "Comments paragraph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-paragraph-atpt (&optional arg ispec) 
  "Doublequotes paragraph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'doublequote arg ispec))

;;;###autoload
(defun singlequote-paragraph-atpt (&optional arg ispec) 
  "Singlequotes paragraph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'singlequote arg ispec))

;;;###autoload
(defun parenthese-paragraph-atpt (&optional arg ispec) 
  "Parentizes paragraph at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'paragraph 'parentize arg ispec))

;;;###autoload
(defun brace-paragraph-atpt (&optional arg ispec) 
  "Braces paragraph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'brace arg ispec))

;;;###autoload
(defun bracket-paragraph-atpt (&optional arg ispec) 
  "Brackets paragraph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'bracket arg ispec))

;;;###autoload
(defun kill-paragraph-atpt ()
  "Kills paragraph at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'paragraph))

;;;###autoload
(defun mark-paragraph-atpt ()
  "Marks paragraph at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'paragraph))

;;;###autoload
(defun forward-paragraph-atpt (&optional arg ispec) 
  "Moves forward over paragraph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-paragraph-atpt (&optional arg ispec) 
  "Moves backward over paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-paragraph-atpt (&optional arg) 
  "Transposes paragraph with paragraph before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-paragraph-atpt arg))
   ;;   (thatpt-transpose 'paragraph arg))
   

;;;###autoload
(defun string-atpt (&optional arg ispec) 
  "Returns string at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-string-atpt (&optional arg ispec) 
  "Returns borders of string at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun string-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-string-atpt (&optional arg ispec) 
  " string at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "string" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "string" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun string-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-string-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class string at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-string-atpt () 
  "Makes a copy of symbol or char-class string at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'string))

;;;###autoload
(defun separate-string-atpt (&optional arg ispec) 
  "Separates string at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-string-atpt (&optional arg ispec) 
  "Comments string at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-string-atpt (&optional arg ispec) 
  "Doublequotes string at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'doublequote arg ispec))

;;;###autoload
(defun singlequote-string-atpt (&optional arg ispec) 
  "Singlequotes string at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'singlequote arg ispec))

;;;###autoload
(defun parenthese-string-atpt (&optional arg ispec) 
  "Parentizes string at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'string 'parentize arg ispec))

;;;###autoload
(defun brace-string-atpt (&optional arg ispec) 
  "Braces string at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'brace arg ispec))

;;;###autoload
(defun bracket-string-atpt (&optional arg ispec) 
  "Brackets string after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'bracket arg ispec))

;;;###autoload
(defun kill-string-atpt ()
  "Kills string at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'string))

;;;###autoload
(defun mark-string-atpt ()
  "Marks string at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'string))

;;;###autoload
(defun forward-string-atpt (&optional arg ispec) 
  "Moves forward over string at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-string-atpt (&optional arg ispec) 
  "Moves backward over string before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-string-atpt (&optional arg) 
  "Transposes string with string before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-string-atpt arg))
   ;;   (thatpt-transpose 'string arg))
   

;;;###autoload
(defun line-atpt (&optional arg ispec) 
  "Returns line at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-line-atpt (&optional arg ispec) 
  "Returns borders of line at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun line-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-line-atpt (&optional arg ispec) 
  " line at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "line" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "line" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun line-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-line-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class line at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-line-atpt () 
  "Makes a copy of symbol or char-class line at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'line))

;;;###autoload
(defun separate-line-atpt (&optional arg ispec) 
  "Separates line at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-line-atpt (&optional arg ispec) 
  "Comments line at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-line-atpt (&optional arg ispec) 
  "Doublequotes line at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'doublequote arg ispec))

;;;###autoload
(defun singlequote-line-atpt (&optional arg ispec) 
  "Singlequotes line at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'singlequote arg ispec))

;;;###autoload
(defun parenthese-line-atpt (&optional arg ispec) 
  "Parentizes line at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'line 'parentize arg ispec))

;;;###autoload
(defun brace-line-atpt (&optional arg ispec) 
  "Braces line at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'brace arg ispec))

;;;###autoload
(defun bracket-line-atpt (&optional arg ispec) 
  "Brackets line after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'bracket arg ispec))

;;;###autoload
(defun kill-line-atpt ()
  "Kills line at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'line))

;;;###autoload
(defun mark-line-atpt ()
  "Marks line at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'line))

;;;###autoload
(defun forward-line-atpt (&optional arg ispec) 
  "Moves forward over line at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-line-atpt (&optional arg ispec) 
  "Moves backward over line before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-line-atpt (&optional arg) 
  "Transposes line with line before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-line-atpt arg))
   ;;   (thatpt-transpose 'line arg))
   

;;;###autoload
(defun sentence-atpt (&optional arg ispec) 
  "Returns sentence at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-sentence-atpt (&optional arg ispec) 
  "Returns borders of sentence at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun sentence-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-sentence-atpt (&optional arg ispec) 
  " sentence at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "sentence" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "sentence" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun sentence-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-sentence-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-sentence-atpt () 
  "Makes a copy of symbol or char-class sentence at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'sentence))

;;;###autoload
(defun separate-sentence-atpt (&optional arg ispec) 
  "Separates sentence at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-sentence-atpt (&optional arg ispec) 
  "Comments sentence at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-sentence-atpt (&optional arg ispec) 
  "Doublequotes sentence at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'doublequote arg ispec))

;;;###autoload
(defun singlequote-sentence-atpt (&optional arg ispec) 
  "Singlequotes sentence at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'singlequote arg ispec))

;;;###autoload
(defun parenthese-sentence-atpt (&optional arg ispec) 
  "Parentizes sentence at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'sentence 'parentize arg ispec))

;;;###autoload
(defun brace-sentence-atpt (&optional arg ispec) 
  "Braces sentence at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'brace arg ispec))

;;;###autoload
(defun bracket-sentence-atpt (&optional arg ispec) 
  "Brackets sentence after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'bracket arg ispec))

;;;###autoload
(defun kill-sentence-atpt ()
  "Kills sentence at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'sentence))

;;;###autoload
(defun mark-sentence-atpt ()
  "Marks sentence at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'sentence))

;;;###autoload
(defun forward-sentence-atpt (&optional arg ispec) 
  "Moves forward over sentence at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-sentence-atpt (&optional arg ispec) 
  "Moves backward over sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-sentence-atpt (&optional arg) 
  "Transposes sentence with sentence before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-sentence-atpt arg))
   ;;   (thatpt-transpose 'sentence arg))
   

;;;###autoload
(defun defun-atpt (&optional arg ispec) 
  "Returns defun at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-defun-atpt (&optional arg ispec) 
  "Returns borders of defun at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun defun-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-defun-atpt (&optional arg ispec) 
  " defun at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "defun" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "defun" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun defun-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-defun-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class defun at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-defun-atpt () 
  "Makes a copy of symbol or char-class defun at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'defun))

;;;###autoload
(defun separate-defun-atpt (&optional arg ispec) 
  "Separates defun at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-defun-atpt (&optional arg ispec) 
  "Comments defun at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-defun-atpt (&optional arg ispec) 
  "Doublequotes defun at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'doublequote arg ispec))

;;;###autoload
(defun singlequote-defun-atpt (&optional arg ispec) 
  "Singlequotes defun at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'singlequote arg ispec))

;;;###autoload
(defun parenthese-defun-atpt (&optional arg ispec) 
  "Parentizes defun at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'defun 'parentize arg ispec))

;;;###autoload
(defun brace-defun-atpt (&optional arg ispec) 
  "Braces defun at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'brace arg ispec))

;;;###autoload
(defun bracket-defun-atpt (&optional arg ispec) 
  "Brackets defun after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'bracket arg ispec))

;;;###autoload
(defun kill-defun-atpt ()
  "Kills defun at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'defun))

;;;###autoload
(defun mark-defun-atpt ()
  "Marks defun at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'defun))

;;;###autoload
(defun forward-defun-atpt (&optional arg ispec) 
  "Moves forward over defun at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-defun-atpt (&optional arg ispec) 
  "Moves backward over defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-defun-atpt (&optional arg) 
  "Transposes defun with defun before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-defun-atpt arg))
   ;;   (thatpt-transpose 'defun arg))
   

;;;###autoload
(defun email-atpt (&optional arg ispec) 
  "Returns email at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-email-atpt (&optional arg ispec) 
  "Returns borders of email at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun email-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-email-atpt (&optional arg ispec) 
  " email at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "email" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "email" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun email-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-email-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class email at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-email-atpt () 
  "Makes a copy of symbol or char-class email at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'email))

;;;###autoload
(defun separate-email-atpt (&optional arg ispec) 
  "Separates email at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-email-atpt (&optional arg ispec) 
  "Comments email at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-email-atpt (&optional arg ispec) 
  "Doublequotes email at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'doublequote arg ispec))

;;;###autoload
(defun singlequote-email-atpt (&optional arg ispec) 
  "Singlequotes email at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'singlequote arg ispec))

;;;###autoload
(defun parenthese-email-atpt (&optional arg ispec) 
  "Parentizes email at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'email 'parentize arg ispec))

;;;###autoload
(defun brace-email-atpt (&optional arg ispec) 
  "Braces email at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'brace arg ispec))

;;;###autoload
(defun bracket-email-atpt (&optional arg ispec) 
  "Brackets email after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'bracket arg ispec))

;;;###autoload
(defun kill-email-atpt ()
  "Kills email at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'email))

;;;###autoload
(defun mark-email-atpt ()
  "Marks email at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'email))

;;;###autoload
(defun forward-email-atpt (&optional arg ispec) 
  "Moves forward over email at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-email-atpt (&optional arg ispec) 
  "Moves backward over email before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-email-atpt (&optional arg) 
  "Transposes email with email before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-email-atpt arg))
   ;;   (thatpt-transpose 'email arg))
   

;;;###autoload
(defun csv-atpt (&optional arg ispec) 
  "Returns csv at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-csv-atpt (&optional arg ispec) 
  "Returns borders of csv at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun csv-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-csv-atpt (&optional arg ispec) 
  " csv at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "csv" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "csv" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun csv-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-csv-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class csv at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-csv-atpt () 
  "Makes a copy of symbol or char-class csv at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'csv))

;;;###autoload
(defun separate-csv-atpt (&optional arg ispec) 
  "Separates csv at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-csv-atpt (&optional arg ispec) 
  "Comments csv at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-csv-atpt (&optional arg ispec) 
  "Doublequotes csv at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'doublequote arg ispec))

;;;###autoload
(defun singlequote-csv-atpt (&optional arg ispec) 
  "Singlequotes csv at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'singlequote arg ispec))

;;;###autoload
(defun parenthese-csv-atpt (&optional arg ispec) 
  "Parentizes csv at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'csv 'parentize arg ispec))

;;;###autoload
(defun brace-csv-atpt (&optional arg ispec) 
  "Braces csv at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'brace arg ispec))

;;;###autoload
(defun bracket-csv-atpt (&optional arg ispec) 
  "Brackets csv after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'bracket arg ispec))

;;;###autoload
(defun kill-csv-atpt ()
  "Kills csv at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'csv))

;;;###autoload
(defun mark-csv-atpt ()
  "Marks csv at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'csv))

;;;###autoload
(defun forward-csv-atpt (&optional arg ispec) 
  "Moves forward over csv at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-csv-atpt (&optional arg ispec) 
  "Moves backward over csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-csv-atpt (&optional arg) 
  "Transposes csv with csv before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-csv-atpt arg))
   ;;   (thatpt-transpose 'csv arg))
   

;;;###autoload
(defun phone-atpt (&optional arg ispec) 
  "Returns phone at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-phone-atpt (&optional arg ispec) 
  "Returns borders of phone at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun phone-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-phone-atpt (&optional arg ispec) 
  " phone at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "phone" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "phone" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun phone-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-phone-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class phone at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-phone-atpt () 
  "Makes a copy of symbol or char-class phone at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'phone))

;;;###autoload
(defun separate-phone-atpt (&optional arg ispec) 
  "Separates phone at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-phone-atpt (&optional arg ispec) 
  "Comments phone at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-phone-atpt (&optional arg ispec) 
  "Doublequotes phone at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'doublequote arg ispec))

;;;###autoload
(defun singlequote-phone-atpt (&optional arg ispec) 
  "Singlequotes phone at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'singlequote arg ispec))

;;;###autoload
(defun parenthese-phone-atpt (&optional arg ispec) 
  "Parentizes phone at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'phone 'parentize arg ispec))

;;;###autoload
(defun brace-phone-atpt (&optional arg ispec) 
  "Braces phone at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'brace arg ispec))

;;;###autoload
(defun bracket-phone-atpt (&optional arg ispec) 
  "Brackets phone after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'bracket arg ispec))

;;;###autoload
(defun kill-phone-atpt ()
  "Kills phone at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'phone))

;;;###autoload
(defun mark-phone-atpt ()
  "Marks phone at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'phone))

;;;###autoload
(defun forward-phone-atpt (&optional arg ispec) 
  "Moves forward over phone at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-phone-atpt (&optional arg ispec) 
  "Moves backward over phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-phone-atpt (&optional arg) 
  "Transposes phone with phone before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-phone-atpt arg))
   ;;   (thatpt-transpose 'phone arg))
   

;;;###autoload
(defun ml-text-atpt (&optional arg ispec) 
  "Returns ml-text at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-ml-text-atpt (&optional arg ispec) 
  "Returns borders of ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun ml-text-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-ml-text-atpt (&optional arg ispec) 
  " ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "ml-text" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "ml-text" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun ml-text-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-ml-text-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-ml-text-atpt () 
  "Makes a copy of symbol or char-class ml-text at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'ml-text))

;;;###autoload
(defun separate-ml-text-atpt (&optional arg ispec) 
  "Separates ml-text at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-ml-text-atpt (&optional arg ispec) 
  "Comments ml-text at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-ml-text-atpt (&optional arg ispec) 
  "Doublequotes ml-text at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'doublequote arg ispec))

;;;###autoload
(defun singlequote-ml-text-atpt (&optional arg ispec) 
  "Singlequotes ml-text at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'singlequote arg ispec))

;;;###autoload
(defun parenthese-ml-text-atpt (&optional arg ispec) 
  "Parentizes ml-text at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'ml-text 'parentize arg ispec))

;;;###autoload
(defun brace-ml-text-atpt (&optional arg ispec) 
  "Braces ml-text at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'brace arg ispec))

;;;###autoload
(defun bracket-ml-text-atpt (&optional arg ispec) 
  "Brackets ml-text after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'bracket arg ispec))

;;;###autoload
(defun kill-ml-text-atpt ()
  "Kills ml-text at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'ml-text))

;;;###autoload
(defun mark-ml-text-atpt ()
  "Marks ml-text at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'ml-text))

;;;###autoload
(defun forward-ml-text-atpt (&optional arg ispec) 
  "Moves forward over ml-text at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-ml-text-atpt (&optional arg ispec) 
  "Moves backward over ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-ml-text-atpt (&optional arg) 
  "Transposes ml-text with ml-text before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-ml-text-atpt arg))
   ;;   (thatpt-transpose 'ml-text arg))
   

;;;###autoload
(defun filename-atpt (&optional arg ispec) 
  "Returns filename at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-filename-atpt (&optional arg ispec) 
  "Returns borders of filename at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun filename-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-filename-atpt (&optional arg ispec) 
  " filename at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "filename" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "filename" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun filename-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-filename-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class filename at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-filename-atpt () 
  "Makes a copy of symbol or char-class filename at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'filename))

;;;###autoload
(defun separate-filename-atpt (&optional arg ispec) 
  "Separates filename at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-filename-atpt (&optional arg ispec) 
  "Comments filename at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-filename-atpt (&optional arg ispec) 
  "Doublequotes filename at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'doublequote arg ispec))

;;;###autoload
(defun singlequote-filename-atpt (&optional arg ispec) 
  "Singlequotes filename at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'singlequote arg ispec))

;;;###autoload
(defun parenthese-filename-atpt (&optional arg ispec) 
  "Parentizes filename at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'filename 'parentize arg ispec))

;;;###autoload
(defun brace-filename-atpt (&optional arg ispec) 
  "Braces filename at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'brace arg ispec))

;;;###autoload
(defun bracket-filename-atpt (&optional arg ispec) 
  "Brackets filename after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'bracket arg ispec))

;;;###autoload
(defun kill-filename-atpt ()
  "Kills filename at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'filename))

;;;###autoload
(defun mark-filename-atpt ()
  "Marks filename at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'filename))

;;;###autoload
(defun forward-filename-atpt (&optional arg ispec) 
  "Moves forward over filename at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-filename-atpt (&optional arg ispec) 
  "Moves backward over filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-filename-atpt (&optional arg) 
  "Transposes filename with filename before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-filename-atpt arg))
   ;;   (thatpt-transpose 'filename arg))
   

;;;###autoload
(defun url-atpt (&optional arg ispec) 
  "Returns url at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-url-atpt (&optional arg ispec) 
  "Returns borders of url at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun url-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-url-atpt (&optional arg ispec) 
  " url at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "url" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "url" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun url-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-url-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class url at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-url-atpt () 
  "Makes a copy of symbol or char-class url at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'url))

;;;###autoload
(defun separate-url-atpt (&optional arg ispec) 
  "Separates url at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-url-atpt (&optional arg ispec) 
  "Comments url at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-url-atpt (&optional arg ispec) 
  "Doublequotes url at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'doublequote arg ispec))

;;;###autoload
(defun singlequote-url-atpt (&optional arg ispec) 
  "Singlequotes url at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'singlequote arg ispec))

;;;###autoload
(defun parenthese-url-atpt (&optional arg ispec) 
  "Parentizes url at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'url 'parentize arg ispec))

;;;###autoload
(defun brace-url-atpt (&optional arg ispec) 
  "Braces url at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'brace arg ispec))

;;;###autoload
(defun bracket-url-atpt (&optional arg ispec) 
  "Brackets url after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'bracket arg ispec))

;;;###autoload
(defun kill-url-atpt ()
  "Kills url at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'url))

;;;###autoload
(defun mark-url-atpt ()
  "Marks url at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'url))

;;;###autoload
(defun forward-url-atpt (&optional arg ispec) 
  "Moves forward over url at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-url-atpt (&optional arg ispec) 
  "Moves backward over url before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-url-atpt (&optional arg) 
  "Transposes url with url before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-url-atpt arg))
   ;;   (thatpt-transpose 'url arg))
   

;;;###autoload
(defun isbn-atpt (&optional arg ispec) 
  "Returns isbn at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-isbn-atpt (&optional arg ispec) 
  "Returns borders of isbn at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun isbn-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-isbn-atpt (&optional arg ispec) 
  " isbn at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "isbn" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "isbn" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun isbn-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-isbn-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-isbn-atpt () 
  "Makes a copy of symbol or char-class isbn at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'isbn))

;;;###autoload
(defun separate-isbn-atpt (&optional arg ispec) 
  "Separates isbn at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-isbn-atpt (&optional arg ispec) 
  "Comments isbn at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-isbn-atpt (&optional arg ispec) 
  "Doublequotes isbn at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'doublequote arg ispec))

;;;###autoload
(defun singlequote-isbn-atpt (&optional arg ispec) 
  "Singlequotes isbn at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'singlequote arg ispec))

;;;###autoload
(defun parenthese-isbn-atpt (&optional arg ispec) 
  "Parentizes isbn at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'isbn 'parentize arg ispec))

;;;###autoload
(defun brace-isbn-atpt (&optional arg ispec) 
  "Braces isbn at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'brace arg ispec))

;;;###autoload
(defun bracket-isbn-atpt (&optional arg ispec) 
  "Brackets isbn after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'bracket arg ispec))

;;;###autoload
(defun kill-isbn-atpt ()
  "Kills isbn at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'isbn))

;;;###autoload
(defun mark-isbn-atpt ()
  "Marks isbn at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'isbn))

;;;###autoload
(defun forward-isbn-atpt (&optional arg ispec) 
  "Moves forward over isbn at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-isbn-atpt (&optional arg ispec) 
  "Moves backward over isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-isbn-atpt (&optional arg) 
  "Transposes isbn with isbn before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-isbn-atpt arg))
   ;;   (thatpt-transpose 'isbn arg))
   

;;;###autoload
(defun date-atpt (&optional arg ispec) 
  "Returns date at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-date-atpt (&optional arg ispec) 
  "Returns borders of date at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun date-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-date-atpt (&optional arg ispec) 
  " date at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "date" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "date" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun date-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-date-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class date at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-date-atpt () 
  "Makes a copy of symbol or char-class date at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'date))

;;;###autoload
(defun separate-date-atpt (&optional arg ispec) 
  "Separates date at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-date-atpt (&optional arg ispec) 
  "Comments date at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-date-atpt (&optional arg ispec) 
  "Doublequotes date at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'doublequote arg ispec))

;;;###autoload
(defun singlequote-date-atpt (&optional arg ispec) 
  "Singlequotes date at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'singlequote arg ispec))

;;;###autoload
(defun parenthese-date-atpt (&optional arg ispec) 
  "Parentizes date at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'date 'parentize arg ispec))

;;;###autoload
(defun brace-date-atpt (&optional arg ispec) 
  "Braces date at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'brace arg ispec))

;;;###autoload
(defun bracket-date-atpt (&optional arg ispec) 
  "Brackets date after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'bracket arg ispec))

;;;###autoload
(defun kill-date-atpt ()
  "Kills date at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'date))

;;;###autoload
(defun mark-date-atpt ()
  "Marks date at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'date))

;;;###autoload
(defun forward-date-atpt (&optional arg ispec) 
  "Moves forward over date at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-date-atpt (&optional arg ispec) 
  "Moves backward over date before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-date-atpt (&optional arg) 
  "Transposes date with date before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-date-atpt arg))
   ;;   (thatpt-transpose 'date arg))
   

;;;###autoload
(defun number-atpt (&optional arg ispec) 
  "Returns number at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-number-atpt (&optional arg ispec) 
  "Returns borders of number at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun number-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-number-atpt (&optional arg ispec) 
  " number at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "number" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "number" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun number-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-number-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class number at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-number-atpt () 
  "Makes a copy of symbol or char-class number at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'number))

;;;###autoload
(defun separate-number-atpt (&optional arg ispec) 
  "Separates number at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-number-atpt (&optional arg ispec) 
  "Comments number at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-number-atpt (&optional arg ispec) 
  "Doublequotes number at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'doublequote arg ispec))

;;;###autoload
(defun singlequote-number-atpt (&optional arg ispec) 
  "Singlequotes number at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'singlequote arg ispec))

;;;###autoload
(defun parenthese-number-atpt (&optional arg ispec) 
  "Parentizes number at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'number 'parentize arg ispec))

;;;###autoload
(defun brace-number-atpt (&optional arg ispec) 
  "Braces number at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'brace arg ispec))

;;;###autoload
(defun bracket-number-atpt (&optional arg ispec) 
  "Brackets number after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'bracket arg ispec))

;;;###autoload
(defun kill-number-atpt ()
  "Kills number at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'number))

;;;###autoload
(defun mark-number-atpt ()
  "Marks number at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'number))

;;;###autoload
(defun forward-number-atpt (&optional arg ispec) 
  "Moves forward over number at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-number-atpt (&optional arg ispec) 
  "Moves backward over number before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-number-atpt (&optional arg) 
  "Transposes number with number before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-number-atpt arg))
   ;;   (thatpt-transpose 'number arg))
   

;;;###autoload
(defun float-atpt (&optional arg ispec) 
  "Returns float at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-float-atpt (&optional arg ispec) 
  "Returns borders of float at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun float-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-float-atpt (&optional arg ispec) 
  " float at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "float" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "float" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun float-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-float-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class float at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-float-atpt () 
  "Makes a copy of symbol or char-class float at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'float))

;;;###autoload
(defun separate-float-atpt (&optional arg ispec) 
  "Separates float at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-float-atpt (&optional arg ispec) 
  "Comments float at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-float-atpt (&optional arg ispec) 
  "Doublequotes float at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'doublequote arg ispec))

;;;###autoload
(defun singlequote-float-atpt (&optional arg ispec) 
  "Singlequotes float at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'singlequote arg ispec))

;;;###autoload
(defun parenthese-float-atpt (&optional arg ispec) 
  "Parentizes float at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'float 'parentize arg ispec))

;;;###autoload
(defun brace-float-atpt (&optional arg ispec) 
  "Braces float at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'brace arg ispec))

;;;###autoload
(defun bracket-float-atpt (&optional arg ispec) 
  "Brackets float after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'bracket arg ispec))

;;;###autoload
(defun kill-float-atpt ()
  "Kills float at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'float))

;;;###autoload
(defun mark-float-atpt ()
  "Marks float at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'float))

;;;###autoload
(defun forward-float-atpt (&optional arg ispec) 
  "Moves forward over float at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-float-atpt (&optional arg ispec) 
  "Moves backward over float before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-float-atpt (&optional arg) 
  "Transposes float with float before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-float-atpt arg))
   ;;   (thatpt-transpose 'float arg))
   

;;;###autoload
(defun page-atpt (&optional arg ispec) 
  "Returns page at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-page-atpt (&optional arg ispec) 
  "Returns borders of page at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun page-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-page-atpt (&optional arg ispec) 
  " page at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "page" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "page" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun page-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-page-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class page at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-page-atpt () 
  "Makes a copy of symbol or char-class page at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'page))

;;;###autoload
(defun separate-page-atpt (&optional arg ispec) 
  "Separates page at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-page-atpt (&optional arg ispec) 
  "Comments page at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-page-atpt (&optional arg ispec) 
  "Doublequotes page at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'doublequote arg ispec))

;;;###autoload
(defun singlequote-page-atpt (&optional arg ispec) 
  "Singlequotes page at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'singlequote arg ispec))

;;;###autoload
(defun parenthese-page-atpt (&optional arg ispec) 
  "Parentizes page at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'page 'parentize arg ispec))

;;;###autoload
(defun brace-page-atpt (&optional arg ispec) 
  "Braces page at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'brace arg ispec))

;;;###autoload
(defun bracket-page-atpt (&optional arg ispec) 
  "Brackets page after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'bracket arg ispec))

;;;###autoload
(defun kill-page-atpt ()
  "Kills page at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'page))

;;;###autoload
(defun mark-page-atpt ()
  "Marks page at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'page))

;;;###autoload
(defun forward-page-atpt (&optional arg ispec) 
  "Moves forward over page at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-page-atpt (&optional arg ispec) 
  "Moves backward over page before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-page-atpt (&optional arg) 
  "Transposes page with page before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-page-atpt arg))
   ;;   (thatpt-transpose 'page arg))
   

;;;###autoload
(defun whitespace-atpt (&optional arg ispec) 
  "Returns whitespace at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-whitespace-atpt (&optional arg ispec) 
  "Returns borders of whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun whitespace-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-whitespace-atpt (&optional arg ispec) 
  " whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "whitespace" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "whitespace" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun whitespace-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-whitespace-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-whitespace-atpt () 
  "Makes a copy of symbol or char-class whitespace at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'whitespace))

;;;###autoload
(defun separate-whitespace-atpt (&optional arg ispec) 
  "Separates whitespace at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-whitespace-atpt (&optional arg ispec) 
  "Comments whitespace at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-whitespace-atpt (&optional arg ispec) 
  "Doublequotes whitespace at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'doublequote arg ispec))

;;;###autoload
(defun singlequote-whitespace-atpt (&optional arg ispec) 
  "Singlequotes whitespace at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'singlequote arg ispec))

;;;###autoload
(defun parenthese-whitespace-atpt (&optional arg ispec) 
  "Parentizes whitespace at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'whitespace 'parentize arg ispec))

;;;###autoload
(defun brace-whitespace-atpt (&optional arg ispec) 
  "Braces whitespace at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'brace arg ispec))

;;;###autoload
(defun bracket-whitespace-atpt (&optional arg ispec) 
  "Brackets whitespace after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'bracket arg ispec))

;;;###autoload
(defun kill-whitespace-atpt ()
  "Kills whitespace at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'whitespace))

;;;###autoload
(defun mark-whitespace-atpt ()
  "Marks whitespace at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'whitespace))

;;;###autoload
(defun forward-whitespace-atpt (&optional arg ispec) 
  "Moves forward over whitespace at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-whitespace-atpt (&optional arg ispec) 
  "Moves backward over whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-whitespace-atpt (&optional arg) 
  "Transposes whitespace with whitespace before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-whitespace-atpt arg))
   ;;   (thatpt-transpose 'whitespace arg))
   

;;;###autoload
(defun alnum-atpt (&optional arg ispec) 
  "Returns alnum at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-alnum-atpt (&optional arg ispec) 
  "Returns borders of alnum at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun alnum-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-alnum-atpt (&optional arg ispec) 
  " alnum at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "alnum" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "alnum" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun alnum-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-alnum-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-alnum-atpt () 
  "Makes a copy of symbol or char-class alnum at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'alnum))

;;;###autoload
(defun separate-alnum-atpt (&optional arg ispec) 
  "Separates alnum at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-alnum-atpt (&optional arg ispec) 
  "Comments alnum at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-alnum-atpt (&optional arg ispec) 
  "Doublequotes alnum at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'doublequote arg ispec))

;;;###autoload
(defun singlequote-alnum-atpt (&optional arg ispec) 
  "Singlequotes alnum at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'singlequote arg ispec))

;;;###autoload
(defun parenthese-alnum-atpt (&optional arg ispec) 
  "Parentizes alnum at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'alnum 'parentize arg ispec))

;;;###autoload
(defun brace-alnum-atpt (&optional arg ispec) 
  "Braces alnum at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'brace arg ispec))

;;;###autoload
(defun bracket-alnum-atpt (&optional arg ispec) 
  "Brackets alnum after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'bracket arg ispec))

;;;###autoload
(defun kill-alnum-atpt ()
  "Kills alnum at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'alnum))

;;;###autoload
(defun mark-alnum-atpt ()
  "Marks alnum at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'alnum))

;;;###autoload
(defun forward-alnum-atpt (&optional arg ispec) 
  "Moves forward over alnum at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-alnum-atpt (&optional arg ispec) 
  "Moves backward over alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-alnum-atpt (&optional arg) 
  "Transposes alnum with alnum before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-alnum-atpt arg))
   ;;   (thatpt-transpose 'alnum arg))
   

;;;###autoload
(defun alpha-atpt (&optional arg ispec) 
  "Returns alpha at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-alpha-atpt (&optional arg ispec) 
  "Returns borders of alpha at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun alpha-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-alpha-atpt (&optional arg ispec) 
  " alpha at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "alpha" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "alpha" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun alpha-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-alpha-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-alpha-atpt () 
  "Makes a copy of symbol or char-class alpha at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'alpha))

;;;###autoload
(defun separate-alpha-atpt (&optional arg ispec) 
  "Separates alpha at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-alpha-atpt (&optional arg ispec) 
  "Comments alpha at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-alpha-atpt (&optional arg ispec) 
  "Doublequotes alpha at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'doublequote arg ispec))

;;;###autoload
(defun singlequote-alpha-atpt (&optional arg ispec) 
  "Singlequotes alpha at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'singlequote arg ispec))

;;;###autoload
(defun parenthese-alpha-atpt (&optional arg ispec) 
  "Parentizes alpha at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'alpha 'parentize arg ispec))

;;;###autoload
(defun brace-alpha-atpt (&optional arg ispec) 
  "Braces alpha at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'brace arg ispec))

;;;###autoload
(defun bracket-alpha-atpt (&optional arg ispec) 
  "Brackets alpha after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'bracket arg ispec))

;;;###autoload
(defun kill-alpha-atpt ()
  "Kills alpha at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'alpha))

;;;###autoload
(defun mark-alpha-atpt ()
  "Marks alpha at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'alpha))

;;;###autoload
(defun forward-alpha-atpt (&optional arg ispec) 
  "Moves forward over alpha at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-alpha-atpt (&optional arg ispec) 
  "Moves backward over alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-alpha-atpt (&optional arg) 
  "Transposes alpha with alpha before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-alpha-atpt arg))
   ;;   (thatpt-transpose 'alpha arg))
   

;;;###autoload
(defun ascii-atpt (&optional arg ispec) 
  "Returns ascii at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-ascii-atpt (&optional arg ispec) 
  "Returns borders of ascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun ascii-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-ascii-atpt (&optional arg ispec) 
  " ascii at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "ascii" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "ascii" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun ascii-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-ascii-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-ascii-atpt () 
  "Makes a copy of symbol or char-class ascii at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'ascii))

;;;###autoload
(defun separate-ascii-atpt (&optional arg ispec) 
  "Separates ascii at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-ascii-atpt (&optional arg ispec) 
  "Comments ascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-ascii-atpt (&optional arg ispec) 
  "Doublequotes ascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'doublequote arg ispec))

;;;###autoload
(defun singlequote-ascii-atpt (&optional arg ispec) 
  "Singlequotes ascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'singlequote arg ispec))

;;;###autoload
(defun parenthese-ascii-atpt (&optional arg ispec) 
  "Parentizes ascii at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'ascii 'parentize arg ispec))

;;;###autoload
(defun brace-ascii-atpt (&optional arg ispec) 
  "Braces ascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'brace arg ispec))

;;;###autoload
(defun bracket-ascii-atpt (&optional arg ispec) 
  "Brackets ascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'bracket arg ispec))

;;;###autoload
(defun kill-ascii-atpt ()
  "Kills ascii at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'ascii))

;;;###autoload
(defun mark-ascii-atpt ()
  "Marks ascii at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'ascii))

;;;###autoload
(defun forward-ascii-atpt (&optional arg ispec) 
  "Moves forward over ascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-ascii-atpt (&optional arg ispec) 
  "Moves backward over ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-ascii-atpt (&optional arg) 
  "Transposes ascii with ascii before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-ascii-atpt arg))
   ;;   (thatpt-transpose 'ascii arg))
   

;;;###autoload
(defun blank-atpt (&optional arg ispec) 
  "Returns blank at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-blank-atpt (&optional arg ispec) 
  "Returns borders of blank at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun blank-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-blank-atpt (&optional arg ispec) 
  " blank at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "blank" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "blank" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun blank-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-blank-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class blank at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-blank-atpt () 
  "Makes a copy of symbol or char-class blank at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'blank))

;;;###autoload
(defun separate-blank-atpt (&optional arg ispec) 
  "Separates blank at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-blank-atpt (&optional arg ispec) 
  "Comments blank at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-blank-atpt (&optional arg ispec) 
  "Doublequotes blank at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'doublequote arg ispec))

;;;###autoload
(defun singlequote-blank-atpt (&optional arg ispec) 
  "Singlequotes blank at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'singlequote arg ispec))

;;;###autoload
(defun parenthese-blank-atpt (&optional arg ispec) 
  "Parentizes blank at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'blank 'parentize arg ispec))

;;;###autoload
(defun brace-blank-atpt (&optional arg ispec) 
  "Braces blank at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'brace arg ispec))

;;;###autoload
(defun bracket-blank-atpt (&optional arg ispec) 
  "Brackets blank after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'bracket arg ispec))

;;;###autoload
(defun kill-blank-atpt ()
  "Kills blank at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'blank))

;;;###autoload
(defun mark-blank-atpt ()
  "Marks blank at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'blank))

;;;###autoload
(defun forward-blank-atpt (&optional arg ispec) 
  "Moves forward over blank at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-blank-atpt (&optional arg ispec) 
  "Moves backward over blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-blank-atpt (&optional arg) 
  "Transposes blank with blank before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-blank-atpt arg))
   ;;   (thatpt-transpose 'blank arg))
   

;;;###autoload
(defun cntrl-atpt (&optional arg ispec) 
  "Returns cntrl at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-cntrl-atpt (&optional arg ispec) 
  "Returns borders of cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun cntrl-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-cntrl-atpt (&optional arg ispec) 
  " cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "cntrl" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "cntrl" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun cntrl-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-cntrl-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-cntrl-atpt () 
  "Makes a copy of symbol or char-class cntrl at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'cntrl))

;;;###autoload
(defun separate-cntrl-atpt (&optional arg ispec) 
  "Separates cntrl at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-cntrl-atpt (&optional arg ispec) 
  "Comments cntrl at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-cntrl-atpt (&optional arg ispec) 
  "Doublequotes cntrl at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'doublequote arg ispec))

;;;###autoload
(defun singlequote-cntrl-atpt (&optional arg ispec) 
  "Singlequotes cntrl at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'singlequote arg ispec))

;;;###autoload
(defun parenthese-cntrl-atpt (&optional arg ispec) 
  "Parentizes cntrl at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'cntrl 'parentize arg ispec))

;;;###autoload
(defun brace-cntrl-atpt (&optional arg ispec) 
  "Braces cntrl at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'brace arg ispec))

;;;###autoload
(defun bracket-cntrl-atpt (&optional arg ispec) 
  "Brackets cntrl after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'bracket arg ispec))

;;;###autoload
(defun kill-cntrl-atpt ()
  "Kills cntrl at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'cntrl))

;;;###autoload
(defun mark-cntrl-atpt ()
  "Marks cntrl at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'cntrl))

;;;###autoload
(defun forward-cntrl-atpt (&optional arg ispec) 
  "Moves forward over cntrl at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-cntrl-atpt (&optional arg ispec) 
  "Moves backward over cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-cntrl-atpt (&optional arg) 
  "Transposes cntrl with cntrl before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-cntrl-atpt arg))
   ;;   (thatpt-transpose 'cntrl arg))
   

;;;###autoload
(defun digit-atpt (&optional arg ispec) 
  "Returns digit at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-digit-atpt (&optional arg ispec) 
  "Returns borders of digit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun digit-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-digit-atpt (&optional arg ispec) 
  " digit at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "digit" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "digit" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun digit-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-digit-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class digit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-digit-atpt () 
  "Makes a copy of symbol or char-class digit at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'digit))

;;;###autoload
(defun separate-digit-atpt (&optional arg ispec) 
  "Separates digit at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-digit-atpt (&optional arg ispec) 
  "Comments digit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-digit-atpt (&optional arg ispec) 
  "Doublequotes digit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'doublequote arg ispec))

;;;###autoload
(defun singlequote-digit-atpt (&optional arg ispec) 
  "Singlequotes digit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'singlequote arg ispec))

;;;###autoload
(defun parenthese-digit-atpt (&optional arg ispec) 
  "Parentizes digit at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'digit 'parentize arg ispec))

;;;###autoload
(defun brace-digit-atpt (&optional arg ispec) 
  "Braces digit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'brace arg ispec))

;;;###autoload
(defun bracket-digit-atpt (&optional arg ispec) 
  "Brackets digit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'bracket arg ispec))

;;;###autoload
(defun kill-digit-atpt ()
  "Kills digit at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'digit))

;;;###autoload
(defun mark-digit-atpt ()
  "Marks digit at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'digit))

;;;###autoload
(defun forward-digit-atpt (&optional arg ispec) 
  "Moves forward over digit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-digit-atpt (&optional arg ispec) 
  "Moves backward over digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-digit-atpt (&optional arg) 
  "Transposes digit with digit before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-digit-atpt arg))
   ;;   (thatpt-transpose 'digit arg))
   

;;;###autoload
(defun graph-atpt (&optional arg ispec) 
  "Returns graph at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-graph-atpt (&optional arg ispec) 
  "Returns borders of graph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun graph-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-graph-atpt (&optional arg ispec) 
  " graph at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "graph" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "graph" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun graph-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-graph-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class graph at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-graph-atpt () 
  "Makes a copy of symbol or char-class graph at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'graph))

;;;###autoload
(defun separate-graph-atpt (&optional arg ispec) 
  "Separates graph at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-graph-atpt (&optional arg ispec) 
  "Comments graph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-graph-atpt (&optional arg ispec) 
  "Doublequotes graph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'doublequote arg ispec))

;;;###autoload
(defun singlequote-graph-atpt (&optional arg ispec) 
  "Singlequotes graph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'singlequote arg ispec))

;;;###autoload
(defun parenthese-graph-atpt (&optional arg ispec) 
  "Parentizes graph at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'graph 'parentize arg ispec))

;;;###autoload
(defun brace-graph-atpt (&optional arg ispec) 
  "Braces graph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'brace arg ispec))

;;;###autoload
(defun bracket-graph-atpt (&optional arg ispec) 
  "Brackets graph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'bracket arg ispec))

;;;###autoload
(defun kill-graph-atpt ()
  "Kills graph at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'graph))

;;;###autoload
(defun mark-graph-atpt ()
  "Marks graph at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'graph))

;;;###autoload
(defun forward-graph-atpt (&optional arg ispec) 
  "Moves forward over graph at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-graph-atpt (&optional arg ispec) 
  "Moves backward over graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-graph-atpt (&optional arg) 
  "Transposes graph with graph before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-graph-atpt arg))
   ;;   (thatpt-transpose 'graph arg))
   

;;;###autoload
(defun lower-atpt (&optional arg ispec) 
  "Returns lower at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-lower-atpt (&optional arg ispec) 
  "Returns borders of lower at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun lower-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-lower-atpt (&optional arg ispec) 
  " lower at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "lower" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "lower" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun lower-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-lower-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class lower at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-lower-atpt () 
  "Makes a copy of symbol or char-class lower at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'lower))

;;;###autoload
(defun separate-lower-atpt (&optional arg ispec) 
  "Separates lower at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-lower-atpt (&optional arg ispec) 
  "Comments lower at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-lower-atpt (&optional arg ispec) 
  "Doublequotes lower at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'doublequote arg ispec))

;;;###autoload
(defun singlequote-lower-atpt (&optional arg ispec) 
  "Singlequotes lower at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'singlequote arg ispec))

;;;###autoload
(defun parenthese-lower-atpt (&optional arg ispec) 
  "Parentizes lower at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'lower 'parentize arg ispec))

;;;###autoload
(defun brace-lower-atpt (&optional arg ispec) 
  "Braces lower at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'brace arg ispec))

;;;###autoload
(defun bracket-lower-atpt (&optional arg ispec) 
  "Brackets lower after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'bracket arg ispec))

;;;###autoload
(defun kill-lower-atpt ()
  "Kills lower at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'lower))

;;;###autoload
(defun mark-lower-atpt ()
  "Marks lower at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'lower))

;;;###autoload
(defun forward-lower-atpt (&optional arg ispec) 
  "Moves forward over lower at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-lower-atpt (&optional arg ispec) 
  "Moves backward over lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-lower-atpt (&optional arg) 
  "Transposes lower with lower before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-lower-atpt arg))
   ;;   (thatpt-transpose 'lower arg))
   

;;;###autoload
(defun multibyte-atpt (&optional arg ispec) 
  "Returns multibyte at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-multibyte-atpt (&optional arg ispec) 
  "Returns borders of multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun multibyte-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-multibyte-atpt (&optional arg ispec) 
  " multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "multibyte" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "multibyte" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun multibyte-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-multibyte-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-multibyte-atpt () 
  "Makes a copy of symbol or char-class multibyte at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'multibyte))

;;;###autoload
(defun separate-multibyte-atpt (&optional arg ispec) 
  "Separates multibyte at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-multibyte-atpt (&optional arg ispec) 
  "Comments multibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-multibyte-atpt (&optional arg ispec) 
  "Doublequotes multibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'doublequote arg ispec))

;;;###autoload
(defun singlequote-multibyte-atpt (&optional arg ispec) 
  "Singlequotes multibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'singlequote arg ispec))

;;;###autoload
(defun parenthese-multibyte-atpt (&optional arg ispec) 
  "Parentizes multibyte at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'multibyte 'parentize arg ispec))

;;;###autoload
(defun brace-multibyte-atpt (&optional arg ispec) 
  "Braces multibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'brace arg ispec))

;;;###autoload
(defun bracket-multibyte-atpt (&optional arg ispec) 
  "Brackets multibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'bracket arg ispec))

;;;###autoload
(defun kill-multibyte-atpt ()
  "Kills multibyte at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'multibyte))

;;;###autoload
(defun mark-multibyte-atpt ()
  "Marks multibyte at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'multibyte))

;;;###autoload
(defun forward-multibyte-atpt (&optional arg ispec) 
  "Moves forward over multibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-multibyte-atpt (&optional arg ispec) 
  "Moves backward over multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-multibyte-atpt (&optional arg) 
  "Transposes multibyte with multibyte before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-multibyte-atpt arg))
   ;;   (thatpt-transpose 'multibyte arg))
   

;;;###autoload
(defun nonascii-atpt (&optional arg ispec) 
  "Returns nonascii at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-nonascii-atpt (&optional arg ispec) 
  "Returns borders of nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun nonascii-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-nonascii-atpt (&optional arg ispec) 
  " nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "nonascii" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "nonascii" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun nonascii-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-nonascii-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-nonascii-atpt () 
  "Makes a copy of symbol or char-class nonascii at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'nonascii))

;;;###autoload
(defun separate-nonascii-atpt (&optional arg ispec) 
  "Separates nonascii at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-nonascii-atpt (&optional arg ispec) 
  "Comments nonascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-nonascii-atpt (&optional arg ispec) 
  "Doublequotes nonascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'doublequote arg ispec))

;;;###autoload
(defun singlequote-nonascii-atpt (&optional arg ispec) 
  "Singlequotes nonascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'singlequote arg ispec))

;;;###autoload
(defun parenthese-nonascii-atpt (&optional arg ispec) 
  "Parentizes nonascii at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'nonascii 'parentize arg ispec))

;;;###autoload
(defun brace-nonascii-atpt (&optional arg ispec) 
  "Braces nonascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'brace arg ispec))

;;;###autoload
(defun bracket-nonascii-atpt (&optional arg ispec) 
  "Brackets nonascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'bracket arg ispec))

;;;###autoload
(defun kill-nonascii-atpt ()
  "Kills nonascii at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'nonascii))

;;;###autoload
(defun mark-nonascii-atpt ()
  "Marks nonascii at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'nonascii))

;;;###autoload
(defun forward-nonascii-atpt (&optional arg ispec) 
  "Moves forward over nonascii at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-nonascii-atpt (&optional arg ispec) 
  "Moves backward over nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-nonascii-atpt (&optional arg) 
  "Transposes nonascii with nonascii before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-nonascii-atpt arg))
   ;;   (thatpt-transpose 'nonascii arg))
   

;;;###autoload
(defun print-atpt (&optional arg ispec) 
  "Returns print at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-print-atpt (&optional arg ispec) 
  "Returns borders of print at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun print-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-print-atpt (&optional arg ispec) 
  " print at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "print" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "print" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun print-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-print-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class print at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-print-atpt () 
  "Makes a copy of symbol or char-class print at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'print))

;;;###autoload
(defun separate-print-atpt (&optional arg ispec) 
  "Separates print at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-print-atpt (&optional arg ispec) 
  "Comments print at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-print-atpt (&optional arg ispec) 
  "Doublequotes print at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'doublequote arg ispec))

;;;###autoload
(defun singlequote-print-atpt (&optional arg ispec) 
  "Singlequotes print at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'singlequote arg ispec))

;;;###autoload
(defun parenthese-print-atpt (&optional arg ispec) 
  "Parentizes print at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'print 'parentize arg ispec))

;;;###autoload
(defun brace-print-atpt (&optional arg ispec) 
  "Braces print at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'brace arg ispec))

;;;###autoload
(defun bracket-print-atpt (&optional arg ispec) 
  "Brackets print after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'bracket arg ispec))

;;;###autoload
(defun kill-print-atpt ()
  "Kills print at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'print))

;;;###autoload
(defun mark-print-atpt ()
  "Marks print at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'print))

;;;###autoload
(defun forward-print-atpt (&optional arg ispec) 
  "Moves forward over print at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-print-atpt (&optional arg ispec) 
  "Moves backward over print before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-print-atpt (&optional arg) 
  "Transposes print with print before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-print-atpt arg))
   ;;   (thatpt-transpose 'print arg))
   

;;;###autoload
(defun punct-atpt (&optional arg ispec) 
  "Returns punct at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-punct-atpt (&optional arg ispec) 
  "Returns borders of punct at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun punct-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-punct-atpt (&optional arg ispec) 
  " punct at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "punct" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "punct" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun punct-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-punct-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class punct at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-punct-atpt () 
  "Makes a copy of symbol or char-class punct at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'punct))

;;;###autoload
(defun separate-punct-atpt (&optional arg ispec) 
  "Separates punct at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-punct-atpt (&optional arg ispec) 
  "Comments punct at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-punct-atpt (&optional arg ispec) 
  "Doublequotes punct at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'doublequote arg ispec))

;;;###autoload
(defun singlequote-punct-atpt (&optional arg ispec) 
  "Singlequotes punct at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'singlequote arg ispec))

;;;###autoload
(defun parenthese-punct-atpt (&optional arg ispec) 
  "Parentizes punct at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'punct 'parentize arg ispec))

;;;###autoload
(defun brace-punct-atpt (&optional arg ispec) 
  "Braces punct at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'brace arg ispec))

;;;###autoload
(defun bracket-punct-atpt (&optional arg ispec) 
  "Brackets punct after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'bracket arg ispec))

;;;###autoload
(defun kill-punct-atpt ()
  "Kills punct at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'punct))

;;;###autoload
(defun mark-punct-atpt ()
  "Marks punct at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'punct))

;;;###autoload
(defun forward-punct-atpt (&optional arg ispec) 
  "Moves forward over punct at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-punct-atpt (&optional arg ispec) 
  "Moves backward over punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-punct-atpt (&optional arg) 
  "Transposes punct with punct before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-punct-atpt arg))
   ;;   (thatpt-transpose 'punct arg))
   

;;;###autoload
(defun space-atpt (&optional arg ispec) 
  "Returns space at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-space-atpt (&optional arg ispec) 
  "Returns borders of space at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun space-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-space-atpt (&optional arg ispec) 
  " space at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "space" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "space" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun space-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-space-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class space at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-space-atpt () 
  "Makes a copy of symbol or char-class space at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'space))

;;;###autoload
(defun separate-space-atpt (&optional arg ispec) 
  "Separates space at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-space-atpt (&optional arg ispec) 
  "Comments space at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-space-atpt (&optional arg ispec) 
  "Doublequotes space at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'doublequote arg ispec))

;;;###autoload
(defun singlequote-space-atpt (&optional arg ispec) 
  "Singlequotes space at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'singlequote arg ispec))

;;;###autoload
(defun parenthese-space-atpt (&optional arg ispec) 
  "Parentizes space at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'space 'parentize arg ispec))

;;;###autoload
(defun brace-space-atpt (&optional arg ispec) 
  "Braces space at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'brace arg ispec))

;;;###autoload
(defun bracket-space-atpt (&optional arg ispec) 
  "Brackets space after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'bracket arg ispec))

;;;###autoload
(defun kill-space-atpt ()
  "Kills space at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'space))

;;;###autoload
(defun mark-space-atpt ()
  "Marks space at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'space))

;;;###autoload
(defun forward-space-atpt (&optional arg ispec) 
  "Moves forward over space at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-space-atpt (&optional arg ispec) 
  "Moves backward over space before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-space-atpt (&optional arg) 
  "Transposes space with space before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-space-atpt arg))
   ;;   (thatpt-transpose 'space arg))
   

;;;###autoload
(defun unibyte-atpt (&optional arg ispec) 
  "Returns unibyte at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-unibyte-atpt (&optional arg ispec) 
  "Returns borders of unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun unibyte-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-unibyte-atpt (&optional arg ispec) 
  " unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "unibyte" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "unibyte" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun unibyte-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-unibyte-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-unibyte-atpt () 
  "Makes a copy of symbol or char-class unibyte at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'unibyte))

;;;###autoload
(defun separate-unibyte-atpt (&optional arg ispec) 
  "Separates unibyte at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-unibyte-atpt (&optional arg ispec) 
  "Comments unibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-unibyte-atpt (&optional arg ispec) 
  "Doublequotes unibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'doublequote arg ispec))

;;;###autoload
(defun singlequote-unibyte-atpt (&optional arg ispec) 
  "Singlequotes unibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'singlequote arg ispec))

;;;###autoload
(defun parenthese-unibyte-atpt (&optional arg ispec) 
  "Parentizes unibyte at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'unibyte 'parentize arg ispec))

;;;###autoload
(defun brace-unibyte-atpt (&optional arg ispec) 
  "Braces unibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'brace arg ispec))

;;;###autoload
(defun bracket-unibyte-atpt (&optional arg ispec) 
  "Brackets unibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'bracket arg ispec))

;;;###autoload
(defun kill-unibyte-atpt ()
  "Kills unibyte at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'unibyte))

;;;###autoload
(defun mark-unibyte-atpt ()
  "Marks unibyte at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'unibyte))

;;;###autoload
(defun forward-unibyte-atpt (&optional arg ispec) 
  "Moves forward over unibyte at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-unibyte-atpt (&optional arg ispec) 
  "Moves backward over unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-unibyte-atpt (&optional arg) 
  "Transposes unibyte with unibyte before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-unibyte-atpt arg))
   ;;   (thatpt-transpose 'unibyte arg))
   

;;;###autoload
(defun upper-atpt (&optional arg ispec) 
  "Returns upper at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-upper-atpt (&optional arg ispec) 
  "Returns borders of upper at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun upper-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-upper-atpt (&optional arg ispec) 
  " upper at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "upper" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "upper" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun upper-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-upper-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class upper at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-upper-atpt () 
  "Makes a copy of symbol or char-class upper at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'upper))

;;;###autoload
(defun separate-upper-atpt (&optional arg ispec) 
  "Separates upper at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-upper-atpt (&optional arg ispec) 
  "Comments upper at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-upper-atpt (&optional arg ispec) 
  "Doublequotes upper at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'doublequote arg ispec))

;;;###autoload
(defun singlequote-upper-atpt (&optional arg ispec) 
  "Singlequotes upper at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'singlequote arg ispec))

;;;###autoload
(defun parenthese-upper-atpt (&optional arg ispec) 
  "Parentizes upper at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'upper 'parentize arg ispec))

;;;###autoload
(defun brace-upper-atpt (&optional arg ispec) 
  "Braces upper at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'brace arg ispec))

;;;###autoload
(defun bracket-upper-atpt (&optional arg ispec) 
  "Brackets upper after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'bracket arg ispec))

;;;###autoload
(defun kill-upper-atpt ()
  "Kills upper at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'upper))

;;;###autoload
(defun mark-upper-atpt ()
  "Marks upper at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'upper))

;;;###autoload
(defun forward-upper-atpt (&optional arg ispec) 
  "Moves forward over upper at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-upper-atpt (&optional arg ispec) 
  "Moves backward over upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-upper-atpt (&optional arg) 
  "Transposes upper with upper before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-upper-atpt arg))
   ;;   (thatpt-transpose 'upper arg))
   

;;;###autoload
(defun xdigit-atpt (&optional arg ispec) 
  "Returns xdigit at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-xdigit-atpt (&optional arg ispec) 
  "Returns borders of xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun xdigit-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-xdigit-atpt (&optional arg ispec) 
  " xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "xdigit" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "xdigit" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun xdigit-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-xdigit-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-xdigit-atpt () 
  "Makes a copy of symbol or char-class xdigit at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'xdigit))

;;;###autoload
(defun separate-xdigit-atpt (&optional arg ispec) 
  "Separates xdigit at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-xdigit-atpt (&optional arg ispec) 
  "Comments xdigit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-xdigit-atpt (&optional arg ispec) 
  "Doublequotes xdigit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'doublequote arg ispec))

;;;###autoload
(defun singlequote-xdigit-atpt (&optional arg ispec) 
  "Singlequotes xdigit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'singlequote arg ispec))

;;;###autoload
(defun parenthese-xdigit-atpt (&optional arg ispec) 
  "Parentizes xdigit at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'xdigit 'parentize arg ispec))

;;;###autoload
(defun brace-xdigit-atpt (&optional arg ispec) 
  "Braces xdigit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'brace arg ispec))

;;;###autoload
(defun bracket-xdigit-atpt (&optional arg ispec) 
  "Brackets xdigit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'bracket arg ispec))

;;;###autoload
(defun kill-xdigit-atpt ()
  "Kills xdigit at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'xdigit))

;;;###autoload
(defun mark-xdigit-atpt ()
  "Marks xdigit at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'xdigit))

;;;###autoload
(defun forward-xdigit-atpt (&optional arg ispec) 
  "Moves forward over xdigit at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-xdigit-atpt (&optional arg ispec) 
  "Moves backward over xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-xdigit-atpt (&optional arg) 
  "Transposes xdigit with xdigit before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-xdigit-atpt arg))
   ;;   (thatpt-transpose 'xdigit arg))
   

;;;###autoload
(defun region-atpt (&optional arg ispec) 
  "Returns region at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-region-atpt (&optional arg ispec) 
  "Returns borders of region at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun region-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-region-atpt (&optional arg ispec) 
  " region at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "region" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "region" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun region-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-region-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class region at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-region-atpt () 
  "Makes a copy of symbol or char-class region at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'region))

;;;###autoload
(defun separate-region-atpt (&optional arg ispec) 
  "Separates region at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-region-atpt (&optional arg ispec) 
  "Comments region at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-region-atpt (&optional arg ispec) 
  "Doublequotes region at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'doublequote arg ispec))

;;;###autoload
(defun singlequote-region-atpt (&optional arg ispec) 
  "Singlequotes region at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'singlequote arg ispec))

;;;###autoload
(defun parenthese-region-atpt (&optional arg ispec) 
  "Parentizes region at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'region 'parentize arg ispec))

;;;###autoload
(defun brace-region-atpt (&optional arg ispec) 
  "Braces region at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'brace arg ispec))

;;;###autoload
(defun bracket-region-atpt (&optional arg ispec) 
  "Brackets region after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'bracket arg ispec))

;;;###autoload
(defun kill-region-atpt ()
  "Kills region at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'region))

;;;###autoload
(defun mark-region-atpt ()
  "Marks region at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'region))

;;;###autoload
(defun forward-region-atpt (&optional arg ispec) 
  "Moves forward over region at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-region-atpt (&optional arg ispec) 
  "Moves backward over region before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-region-atpt (&optional arg) 
  "Transposes region with region before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-region-atpt arg))
   ;;   (thatpt-transpose 'region arg))
   

;;;###autoload
(defun delimited-atpt (&optional arg ispec) 
  "Returns delimited at point if any, nil otherwise"
  (interactive "P\np")
  (thatpt 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun bounds-of-delimited-atpt (&optional arg ispec) 
  "Returns borders of delimited at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-bounds 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun delimited-atpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-beginning 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun check-delimited-atpt (&optional arg ispec) 
  " delimited at point if any, nil otherwise "
  (interactive "P\np")
  (let ((beg (funcall (intern-soft (concat "delimited" "-atpt-beginning-position"))))
	(end (funcall (intern-soft (concat "delimited" "-atpt-end-position")))))
    (thatpt-check beg end arg ispec)))

;;;###autoload
(defun delimited-atpt-end-position (&optional arg ispec) 
  "Returns end position of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-end 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun copy-delimited-atpt (&optional arg ispec) 
  "Makes a copy of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "P\np")
  (thatpt-copy 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun escape-delimited-atpt () 
  "Makes a copy of symbol or char-class delimited at point if any, nil otherwise "
  (interactive "*")
  (thatpt-escape 'delimited))

;;;###autoload
(defun separate-delimited-atpt (&optional arg ispec) 
  "Separates delimited at point if any, does nothing otherwise
  inserts newlines, borders are the beginning or the end of buffer "
  (interactive "P\np")
  (thatpt-separate 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun comment-delimited-atpt (&optional arg ispec) 
  "Comments delimited at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-comment 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun doublequote-delimited-atpt (&optional arg ispec) 
  "Doublequotes delimited at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'doublequote arg ispec))

;;;###autoload
(defun singlequote-delimited-atpt (&optional arg ispec) 
  "Singlequotes delimited at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'singlequote arg ispec))

;;;###autoload
(defun parenthese-delimited-atpt (&optional arg ispec) 
  "Parentizes delimited at point if any, does nothing otherwise"
  (interactive "P\np")
  (thatpt-delim 'delimited 'parentize arg ispec))

;;;###autoload
(defun brace-delimited-atpt (&optional arg ispec) 
  "Braces delimited at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'brace arg ispec))

;;;###autoload
(defun bracket-delimited-atpt (&optional arg ispec) 
  "Brackets delimited after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'bracket arg ispec))

;;;###autoload
(defun kill-delimited-atpt ()
  "Kills delimited at point if any, does nothing otherwise "
  (interactive "*")
  (thatpt-kill 'delimited))

;;;###autoload
(defun mark-delimited-atpt ()
  "Marks delimited at point if any, does nothing otherwise "
  (interactive)
  (thatpt-mark 'delimited))

;;;###autoload
(defun forward-delimited-atpt (&optional arg ispec) 
  "Moves forward over delimited at point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun backward-delimited-atpt (&optional arg ispec) 
  "Moves backward over delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'delimited (prefix-numeric-value arg) ispec))

;;;###autoload
(defun transpose-delimited-atpt (&optional arg) 
  "Transposes delimited with delimited before point if any, does nothing otherwise "
  (interactive "*p")
  (transpose-subr-ar 'forward-delimited-atpt arg))
   ;;   (thatpt-transpose 'delimited arg))
   
(provide 'thing-at-point-utils)
;;; thing-at-point-utils.el ends here
