;;; thing-before-point-utils.el  --- more thing-at-point edit functions

;; Version: 1.5

;; Copyright (C) 2006, 2007 Andreas Roehler

;; Author: Andreas Roehler <andreas.roehler@easy-emacs.de>

;; Keywords: convenience

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Information is given with thingatpt-utils-base.el

(require 'thingatpt-utils-base)


;;;###autoload
(defun list-bfpt (&optional arg ispec) 
  "Returns list before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'list (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-list-bfpt (&optional arg ispec) 
  "Returns border of list before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'list (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun list-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of list before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'list (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun list-bfpt-end-position (&optional arg ispec) 
  "Returns end position of list before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'list (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-list-bfpt (&optional arg ispec) 
  "Returns a copy of list before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'list (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-list-bfpt (&optional arg ispec) 
  "Returns a copy of list before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'list (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-list-bfpt (&optional arg ispec) 
  "Returns a copy of list before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'list (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-list-bfpt (&optional arg ispec) 
  "Doublequotes list before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'list 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-list-bfpt (&optional arg ispec) 
  "Singlequotes list before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'list 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-list-bfpt (&optional arg ispec) 
  "Parentizes list before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'list 'parentize arg ispec))))

;;;###autoload
(defun brace-list-bfpt (&optional arg ispec) 
  "Braces list before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'list 'brace arg ispec))))

;;;###autoload
(defun bracket-list-bfpt (&optional arg ispec) 
  "Brackets list before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'list 'bracket arg ispec))))

;;;###autoload
(defun kill-list-bfpt ()
  "Kills list before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'list))))

;;;###autoload
(defun mark-list-bfpt ()
  "Marks list before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'list))))

;;;###autoload
(defun backward-list-bfpt (&optional arg ispec) 
  "Moves backward over list before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'list (prefix-numeric-value arg) ispec))

;;;###autoload
(defun symbol-bfpt (&optional arg ispec) 
  "Returns symbol before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'symbol (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-symbol-bfpt (&optional arg ispec) 
  "Returns border of symbol before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'symbol (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun symbol-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'symbol (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun symbol-bfpt-end-position (&optional arg ispec) 
  "Returns end position of symbol before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'symbol (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-symbol-bfpt (&optional arg ispec) 
  "Returns a copy of symbol before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'symbol (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-symbol-bfpt (&optional arg ispec) 
  "Returns a copy of symbol before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'symbol (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-symbol-bfpt (&optional arg ispec) 
  "Returns a copy of symbol before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'symbol (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-symbol-bfpt (&optional arg ispec) 
  "Doublequotes symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'symbol 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-symbol-bfpt (&optional arg ispec) 
  "Singlequotes symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'symbol 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-symbol-bfpt (&optional arg ispec) 
  "Parentizes symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'symbol 'parentize arg ispec))))

;;;###autoload
(defun brace-symbol-bfpt (&optional arg ispec) 
  "Braces symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'symbol 'brace arg ispec))))

;;;###autoload
(defun bracket-symbol-bfpt (&optional arg ispec) 
  "Brackets symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'symbol 'bracket arg ispec))))

;;;###autoload
(defun kill-symbol-bfpt ()
  "Kills symbol before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'symbol))))

;;;###autoload
(defun mark-symbol-bfpt ()
  "Marks symbol before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'symbol))))

;;;###autoload
(defun backward-symbol-bfpt (&optional arg ispec) 
  "Moves backward over symbol before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'symbol (prefix-numeric-value arg) ispec))

;;;###autoload
(defun word-bfpt (&optional arg ispec) 
  "Returns word before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'word (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-word-bfpt (&optional arg ispec) 
  "Returns border of word before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'word (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun word-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of word before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'word (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun word-bfpt-end-position (&optional arg ispec) 
  "Returns end position of word before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'word (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-word-bfpt (&optional arg ispec) 
  "Returns a copy of word before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'word (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-word-bfpt (&optional arg ispec) 
  "Returns a copy of word before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'word (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-word-bfpt (&optional arg ispec) 
  "Returns a copy of word before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'word (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-word-bfpt (&optional arg ispec) 
  "Doublequotes word before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'word 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-word-bfpt (&optional arg ispec) 
  "Singlequotes word before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'word 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-word-bfpt (&optional arg ispec) 
  "Parentizes word before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'word 'parentize arg ispec))))

;;;###autoload
(defun brace-word-bfpt (&optional arg ispec) 
  "Braces word before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'word 'brace arg ispec))))

;;;###autoload
(defun bracket-word-bfpt (&optional arg ispec) 
  "Brackets word before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'word 'bracket arg ispec))))

;;;###autoload
(defun kill-word-bfpt ()
  "Kills word before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'word))))

;;;###autoload
(defun mark-word-bfpt ()
  "Marks word before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:word:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'word))))

;;;###autoload
(defun backward-word-bfpt (&optional arg ispec) 
  "Moves backward over word before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'word (prefix-numeric-value arg) ispec))

;;;###autoload
(defun sexp-bfpt (&optional arg ispec) 
  "Returns sexp before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'sexp (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-sexp-bfpt (&optional arg ispec) 
  "Returns border of sexp before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'sexp (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun sexp-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of sexp before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'sexp (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun sexp-bfpt-end-position (&optional arg ispec) 
  "Returns end position of sexp before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'sexp (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-sexp-bfpt (&optional arg ispec) 
  "Returns a copy of sexp before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'sexp (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-sexp-bfpt (&optional arg ispec) 
  "Returns a copy of sexp before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'sexp (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-sexp-bfpt (&optional arg ispec) 
  "Returns a copy of sexp before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'sexp (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-sexp-bfpt (&optional arg ispec) 
  "Doublequotes sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sexp 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-sexp-bfpt (&optional arg ispec) 
  "Singlequotes sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sexp 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-sexp-bfpt (&optional arg ispec) 
  "Parentizes sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sexp 'parentize arg ispec))))

;;;###autoload
(defun brace-sexp-bfpt (&optional arg ispec) 
  "Braces sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sexp 'brace arg ispec))))

;;;###autoload
(defun bracket-sexp-bfpt (&optional arg ispec) 
  "Brackets sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sexp 'bracket arg ispec))))

;;;###autoload
(defun kill-sexp-bfpt ()
  "Kills sexp before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'sexp))))

;;;###autoload
(defun mark-sexp-bfpt ()
  "Marks sexp before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'sexp))))

;;;###autoload
(defun backward-sexp-bfpt (&optional arg ispec) 
  "Moves backward over sexp before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'sexp (prefix-numeric-value arg) ispec))

;;;###autoload
(defun paragraph-bfpt (&optional arg ispec) 
  "Returns paragraph before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'paragraph (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-paragraph-bfpt (&optional arg ispec) 
  "Returns border of paragraph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'paragraph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun paragraph-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of paragraph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'paragraph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun paragraph-bfpt-end-position (&optional arg ispec) 
  "Returns end position of paragraph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'paragraph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-paragraph-bfpt (&optional arg ispec) 
  "Returns a copy of paragraph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'paragraph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-paragraph-bfpt (&optional arg ispec) 
  "Returns a copy of paragraph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'paragraph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-paragraph-bfpt (&optional arg ispec) 
  "Returns a copy of paragraph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'paragraph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-paragraph-bfpt (&optional arg ispec) 
  "Doublequotes paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'paragraph 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-paragraph-bfpt (&optional arg ispec) 
  "Singlequotes paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'paragraph 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-paragraph-bfpt (&optional arg ispec) 
  "Parentizes paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'paragraph 'parentize arg ispec))))

;;;###autoload
(defun brace-paragraph-bfpt (&optional arg ispec) 
  "Braces paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'paragraph 'brace arg ispec))))

;;;###autoload
(defun bracket-paragraph-bfpt (&optional arg ispec) 
  "Brackets paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'paragraph 'bracket arg ispec))))

;;;###autoload
(defun kill-paragraph-bfpt ()
  "Kills paragraph before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'paragraph))))

;;;###autoload
(defun mark-paragraph-bfpt ()
  "Marks paragraph before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'paragraph))))

;;;###autoload
(defun backward-paragraph-bfpt (&optional arg ispec) 
  "Moves backward over paragraph before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'paragraph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun string-bfpt (&optional arg ispec) 
  "Returns string before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'string (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-string-bfpt (&optional arg ispec) 
  "Returns border of string before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'string (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun string-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of string before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'string (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun string-bfpt-end-position (&optional arg ispec) 
  "Returns end position of string before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'string (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-string-bfpt (&optional arg ispec) 
  "Returns a copy of string before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'string (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-string-bfpt (&optional arg ispec) 
  "Returns a copy of string before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'string (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-string-bfpt (&optional arg ispec) 
  "Returns a copy of string before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'string (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-string-bfpt (&optional arg ispec) 
  "Doublequotes string before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'string 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-string-bfpt (&optional arg ispec) 
  "Singlequotes string before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'string 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-string-bfpt (&optional arg ispec) 
  "Parentizes string before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'string 'parentize arg ispec))))

;;;###autoload
(defun brace-string-bfpt (&optional arg ispec) 
  "Braces string before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'string 'brace arg ispec))))

;;;###autoload
(defun bracket-string-bfpt (&optional arg ispec) 
  "Brackets string before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'string 'bracket arg ispec))))

;;;###autoload
(defun kill-string-bfpt ()
  "Kills string before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'string))))

;;;###autoload
(defun mark-string-bfpt ()
  "Marks string before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'string))))

;;;###autoload
(defun backward-string-bfpt (&optional arg ispec) 
  "Moves backward over string before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'string (prefix-numeric-value arg) ispec))

;;;###autoload
(defun line-bfpt (&optional arg ispec) 
  "Returns line before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'line (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-line-bfpt (&optional arg ispec) 
  "Returns border of line before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'line (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun line-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of line before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'line (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun line-bfpt-end-position (&optional arg ispec) 
  "Returns end position of line before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'line (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-line-bfpt (&optional arg ispec) 
  "Returns a copy of line before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'line (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-line-bfpt (&optional arg ispec) 
  "Returns a copy of line before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'line (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-line-bfpt (&optional arg ispec) 
  "Returns a copy of line before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'line (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-line-bfpt (&optional arg ispec) 
  "Doublequotes line before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'line 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-line-bfpt (&optional arg ispec) 
  "Singlequotes line before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'line 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-line-bfpt (&optional arg ispec) 
  "Parentizes line before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'line 'parentize arg ispec))))

;;;###autoload
(defun brace-line-bfpt (&optional arg ispec) 
  "Braces line before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'line 'brace arg ispec))))

;;;###autoload
(defun bracket-line-bfpt (&optional arg ispec) 
  "Brackets line before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'line 'bracket arg ispec))))

;;;###autoload
(defun kill-line-bfpt ()
  "Kills line before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'line))))

;;;###autoload
(defun mark-line-bfpt ()
  "Marks line before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'line))))

;;;###autoload
(defun backward-line-bfpt (&optional arg ispec) 
  "Moves backward over line before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'line (prefix-numeric-value arg) ispec))

;;;###autoload
(defun sentence-bfpt (&optional arg ispec) 
  "Returns sentence before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'sentence (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-sentence-bfpt (&optional arg ispec) 
  "Returns border of sentence before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'sentence (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun sentence-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of sentence before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'sentence (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun sentence-bfpt-end-position (&optional arg ispec) 
  "Returns end position of sentence before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'sentence (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-sentence-bfpt (&optional arg ispec) 
  "Returns a copy of sentence before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'sentence (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-sentence-bfpt (&optional arg ispec) 
  "Returns a copy of sentence before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'sentence (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-sentence-bfpt (&optional arg ispec) 
  "Returns a copy of sentence before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'sentence (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-sentence-bfpt (&optional arg ispec) 
  "Doublequotes sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sentence 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-sentence-bfpt (&optional arg ispec) 
  "Singlequotes sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sentence 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-sentence-bfpt (&optional arg ispec) 
  "Parentizes sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sentence 'parentize arg ispec))))

;;;###autoload
(defun brace-sentence-bfpt (&optional arg ispec) 
  "Braces sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sentence 'brace arg ispec))))

;;;###autoload
(defun bracket-sentence-bfpt (&optional arg ispec) 
  "Brackets sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'sentence 'bracket arg ispec))))

;;;###autoload
(defun kill-sentence-bfpt ()
  "Kills sentence before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'sentence))))

;;;###autoload
(defun mark-sentence-bfpt ()
  "Marks sentence before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'sentence))))

;;;###autoload
(defun backward-sentence-bfpt (&optional arg ispec) 
  "Moves backward over sentence before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'sentence (prefix-numeric-value arg) ispec))

;;;###autoload
(defun defun-bfpt (&optional arg ispec) 
  "Returns defun before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'defun (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-defun-bfpt (&optional arg ispec) 
  "Returns border of defun before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'defun (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun defun-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of defun before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'defun (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun defun-bfpt-end-position (&optional arg ispec) 
  "Returns end position of defun before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'defun (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-defun-bfpt (&optional arg ispec) 
  "Returns a copy of defun before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'defun (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-defun-bfpt (&optional arg ispec) 
  "Returns a copy of defun before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'defun (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-defun-bfpt (&optional arg ispec) 
  "Returns a copy of defun before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'defun (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-defun-bfpt (&optional arg ispec) 
  "Doublequotes defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'defun 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-defun-bfpt (&optional arg ispec) 
  "Singlequotes defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'defun 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-defun-bfpt (&optional arg ispec) 
  "Parentizes defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'defun 'parentize arg ispec))))

;;;###autoload
(defun brace-defun-bfpt (&optional arg ispec) 
  "Braces defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'defun 'brace arg ispec))))

;;;###autoload
(defun bracket-defun-bfpt (&optional arg ispec) 
  "Brackets defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'defun 'bracket arg ispec))))

;;;###autoload
(defun kill-defun-bfpt ()
  "Kills defun before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'defun))))

;;;###autoload
(defun mark-defun-bfpt ()
  "Marks defun before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'defun))))

;;;###autoload
(defun backward-defun-bfpt (&optional arg ispec) 
  "Moves backward over defun before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'defun (prefix-numeric-value arg) ispec))

;;;###autoload
(defun email-bfpt (&optional arg ispec) 
  "Returns email before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'email (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-email-bfpt (&optional arg ispec) 
  "Returns border of email before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'email (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun email-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of email before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'email (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun email-bfpt-end-position (&optional arg ispec) 
  "Returns end position of email before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'email (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-email-bfpt (&optional arg ispec) 
  "Returns a copy of email before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'email (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-email-bfpt (&optional arg ispec) 
  "Returns a copy of email before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'email (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-email-bfpt (&optional arg ispec) 
  "Returns a copy of email before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'email (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-email-bfpt (&optional arg ispec) 
  "Doublequotes email before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'email 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-email-bfpt (&optional arg ispec) 
  "Singlequotes email before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'email 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-email-bfpt (&optional arg ispec) 
  "Parentizes email before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'email 'parentize arg ispec))))

;;;###autoload
(defun brace-email-bfpt (&optional arg ispec) 
  "Braces email before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'email 'brace arg ispec))))

;;;###autoload
(defun bracket-email-bfpt (&optional arg ispec) 
  "Brackets email before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'email 'bracket arg ispec))))

;;;###autoload
(defun kill-email-bfpt ()
  "Kills email before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'email))))

;;;###autoload
(defun mark-email-bfpt ()
  "Marks email before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'email))))

;;;###autoload
(defun backward-email-bfpt (&optional arg ispec) 
  "Moves backward over email before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'email (prefix-numeric-value arg) ispec))

;;;###autoload
(defun csv-bfpt (&optional arg ispec) 
  "Returns csv before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'csv (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-csv-bfpt (&optional arg ispec) 
  "Returns border of csv before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'csv (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun csv-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of csv before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'csv (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun csv-bfpt-end-position (&optional arg ispec) 
  "Returns end position of csv before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'csv (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-csv-bfpt (&optional arg ispec) 
  "Returns a copy of csv before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'csv (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-csv-bfpt (&optional arg ispec) 
  "Returns a copy of csv before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'csv (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-csv-bfpt (&optional arg ispec) 
  "Returns a copy of csv before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'csv (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-csv-bfpt (&optional arg ispec) 
  "Doublequotes csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'csv 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-csv-bfpt (&optional arg ispec) 
  "Singlequotes csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'csv 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-csv-bfpt (&optional arg ispec) 
  "Parentizes csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'csv 'parentize arg ispec))))

;;;###autoload
(defun brace-csv-bfpt (&optional arg ispec) 
  "Braces csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'csv 'brace arg ispec))))

;;;###autoload
(defun bracket-csv-bfpt (&optional arg ispec) 
  "Brackets csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'csv 'bracket arg ispec))))

;;;###autoload
(defun kill-csv-bfpt ()
  "Kills csv before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'csv))))

;;;###autoload
(defun mark-csv-bfpt ()
  "Marks csv before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'csv))))

;;;###autoload
(defun backward-csv-bfpt (&optional arg ispec) 
  "Moves backward over csv before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'csv (prefix-numeric-value arg) ispec))

;;;###autoload
(defun phone-bfpt (&optional arg ispec) 
  "Returns phone before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'phone (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-phone-bfpt (&optional arg ispec) 
  "Returns border of phone before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'phone (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun phone-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of phone before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'phone (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun phone-bfpt-end-position (&optional arg ispec) 
  "Returns end position of phone before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'phone (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-phone-bfpt (&optional arg ispec) 
  "Returns a copy of phone before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'phone (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-phone-bfpt (&optional arg ispec) 
  "Returns a copy of phone before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'phone (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-phone-bfpt (&optional arg ispec) 
  "Returns a copy of phone before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'phone (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-phone-bfpt (&optional arg ispec) 
  "Doublequotes phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'phone 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-phone-bfpt (&optional arg ispec) 
  "Singlequotes phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'phone 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-phone-bfpt (&optional arg ispec) 
  "Parentizes phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'phone 'parentize arg ispec))))

;;;###autoload
(defun brace-phone-bfpt (&optional arg ispec) 
  "Braces phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'phone 'brace arg ispec))))

;;;###autoload
(defun bracket-phone-bfpt (&optional arg ispec) 
  "Brackets phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'phone 'bracket arg ispec))))

;;;###autoload
(defun kill-phone-bfpt ()
  "Kills phone before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'phone))))

;;;###autoload
(defun mark-phone-bfpt ()
  "Marks phone before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'phone))))

;;;###autoload
(defun backward-phone-bfpt (&optional arg ispec) 
  "Moves backward over phone before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'phone (prefix-numeric-value arg) ispec))

;;;###autoload
(defun ml-text-bfpt (&optional arg ispec) 
  "Returns ml-text before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'ml-text (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-ml-text-bfpt (&optional arg ispec) 
  "Returns border of ml-text before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'ml-text (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun ml-text-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of ml-text before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'ml-text (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun ml-text-bfpt-end-position (&optional arg ispec) 
  "Returns end position of ml-text before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'ml-text (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-ml-text-bfpt (&optional arg ispec) 
  "Returns a copy of ml-text before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'ml-text (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-ml-text-bfpt (&optional arg ispec) 
  "Returns a copy of ml-text before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'ml-text (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-ml-text-bfpt (&optional arg ispec) 
  "Returns a copy of ml-text before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'ml-text (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-ml-text-bfpt (&optional arg ispec) 
  "Doublequotes ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ml-text 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-ml-text-bfpt (&optional arg ispec) 
  "Singlequotes ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ml-text 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-ml-text-bfpt (&optional arg ispec) 
  "Parentizes ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ml-text 'parentize arg ispec))))

;;;###autoload
(defun brace-ml-text-bfpt (&optional arg ispec) 
  "Braces ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ml-text 'brace arg ispec))))

;;;###autoload
(defun bracket-ml-text-bfpt (&optional arg ispec) 
  "Brackets ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ml-text 'bracket arg ispec))))

;;;###autoload
(defun kill-ml-text-bfpt ()
  "Kills ml-text before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'ml-text))))

;;;###autoload
(defun mark-ml-text-bfpt ()
  "Marks ml-text before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'ml-text))))

;;;###autoload
(defun backward-ml-text-bfpt (&optional arg ispec) 
  "Moves backward over ml-text before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'ml-text (prefix-numeric-value arg) ispec))

;;;###autoload
(defun filename-bfpt (&optional arg ispec) 
  "Returns filename before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'filename (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-filename-bfpt (&optional arg ispec) 
  "Returns border of filename before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'filename (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun filename-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of filename before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'filename (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun filename-bfpt-end-position (&optional arg ispec) 
  "Returns end position of filename before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'filename (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-filename-bfpt (&optional arg ispec) 
  "Returns a copy of filename before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'filename (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-filename-bfpt (&optional arg ispec) 
  "Returns a copy of filename before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'filename (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-filename-bfpt (&optional arg ispec) 
  "Returns a copy of filename before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'filename (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-filename-bfpt (&optional arg ispec) 
  "Doublequotes filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'filename 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-filename-bfpt (&optional arg ispec) 
  "Singlequotes filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'filename 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-filename-bfpt (&optional arg ispec) 
  "Parentizes filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'filename 'parentize arg ispec))))

;;;###autoload
(defun brace-filename-bfpt (&optional arg ispec) 
  "Braces filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'filename 'brace arg ispec))))

;;;###autoload
(defun bracket-filename-bfpt (&optional arg ispec) 
  "Brackets filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'filename 'bracket arg ispec))))

;;;###autoload
(defun kill-filename-bfpt ()
  "Kills filename before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'filename))))

;;;###autoload
(defun mark-filename-bfpt ()
  "Marks filename before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'filename))))

;;;###autoload
(defun backward-filename-bfpt (&optional arg ispec) 
  "Moves backward over filename before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'filename (prefix-numeric-value arg) ispec))

;;;###autoload
(defun url-bfpt (&optional arg ispec) 
  "Returns url before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'url (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-url-bfpt (&optional arg ispec) 
  "Returns border of url before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'url (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun url-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of url before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'url (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun url-bfpt-end-position (&optional arg ispec) 
  "Returns end position of url before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'url (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-url-bfpt (&optional arg ispec) 
  "Returns a copy of url before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'url (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-url-bfpt (&optional arg ispec) 
  "Returns a copy of url before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'url (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-url-bfpt (&optional arg ispec) 
  "Returns a copy of url before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'url (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-url-bfpt (&optional arg ispec) 
  "Doublequotes url before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'url 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-url-bfpt (&optional arg ispec) 
  "Singlequotes url before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'url 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-url-bfpt (&optional arg ispec) 
  "Parentizes url before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'url 'parentize arg ispec))))

;;;###autoload
(defun brace-url-bfpt (&optional arg ispec) 
  "Braces url before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'url 'brace arg ispec))))

;;;###autoload
(defun bracket-url-bfpt (&optional arg ispec) 
  "Brackets url before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'url 'bracket arg ispec))))

;;;###autoload
(defun kill-url-bfpt ()
  "Kills url before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'url))))

;;;###autoload
(defun mark-url-bfpt ()
  "Marks url before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'url))))

;;;###autoload
(defun backward-url-bfpt (&optional arg ispec) 
  "Moves backward over url before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'url (prefix-numeric-value arg) ispec))

;;;###autoload
(defun isbn-bfpt (&optional arg ispec) 
  "Returns isbn before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'isbn (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-isbn-bfpt (&optional arg ispec) 
  "Returns border of isbn before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'isbn (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun isbn-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of isbn before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'isbn (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun isbn-bfpt-end-position (&optional arg ispec) 
  "Returns end position of isbn before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'isbn (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-isbn-bfpt (&optional arg ispec) 
  "Returns a copy of isbn before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'isbn (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-isbn-bfpt (&optional arg ispec) 
  "Returns a copy of isbn before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'isbn (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-isbn-bfpt (&optional arg ispec) 
  "Returns a copy of isbn before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'isbn (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-isbn-bfpt (&optional arg ispec) 
  "Doublequotes isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'isbn 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-isbn-bfpt (&optional arg ispec) 
  "Singlequotes isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'isbn 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-isbn-bfpt (&optional arg ispec) 
  "Parentizes isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'isbn 'parentize arg ispec))))

;;;###autoload
(defun brace-isbn-bfpt (&optional arg ispec) 
  "Braces isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'isbn 'brace arg ispec))))

;;;###autoload
(defun bracket-isbn-bfpt (&optional arg ispec) 
  "Brackets isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'isbn 'bracket arg ispec))))

;;;###autoload
(defun kill-isbn-bfpt ()
  "Kills isbn before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'isbn))))

;;;###autoload
(defun mark-isbn-bfpt ()
  "Marks isbn before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'isbn))))

;;;###autoload
(defun backward-isbn-bfpt (&optional arg ispec) 
  "Moves backward over isbn before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'isbn (prefix-numeric-value arg) ispec))

;;;###autoload
(defun date-bfpt (&optional arg ispec) 
  "Returns date before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'date (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-date-bfpt (&optional arg ispec) 
  "Returns border of date before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'date (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun date-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of date before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'date (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun date-bfpt-end-position (&optional arg ispec) 
  "Returns end position of date before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'date (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-date-bfpt (&optional arg ispec) 
  "Returns a copy of date before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'date (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-date-bfpt (&optional arg ispec) 
  "Returns a copy of date before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'date (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-date-bfpt (&optional arg ispec) 
  "Returns a copy of date before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'date (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-date-bfpt (&optional arg ispec) 
  "Doublequotes date before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'date 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-date-bfpt (&optional arg ispec) 
  "Singlequotes date before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'date 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-date-bfpt (&optional arg ispec) 
  "Parentizes date before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'date 'parentize arg ispec))))

;;;###autoload
(defun brace-date-bfpt (&optional arg ispec) 
  "Braces date before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'date 'brace arg ispec))))

;;;###autoload
(defun bracket-date-bfpt (&optional arg ispec) 
  "Brackets date before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'date 'bracket arg ispec))))

;;;###autoload
(defun kill-date-bfpt ()
  "Kills date before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'date))))

;;;###autoload
(defun mark-date-bfpt ()
  "Marks date before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'date))))

;;;###autoload
(defun backward-date-bfpt (&optional arg ispec) 
  "Moves backward over date before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'date (prefix-numeric-value arg) ispec))

;;;###autoload
(defun number-bfpt (&optional arg ispec) 
  "Returns number before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'number (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-number-bfpt (&optional arg ispec) 
  "Returns border of number before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'number (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun number-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of number before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'number (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun number-bfpt-end-position (&optional arg ispec) 
  "Returns end position of number before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'number (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-number-bfpt (&optional arg ispec) 
  "Returns a copy of number before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'number (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-number-bfpt (&optional arg ispec) 
  "Returns a copy of number before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'number (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-number-bfpt (&optional arg ispec) 
  "Returns a copy of number before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'number (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-number-bfpt (&optional arg ispec) 
  "Doublequotes number before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'number 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-number-bfpt (&optional arg ispec) 
  "Singlequotes number before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'number 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-number-bfpt (&optional arg ispec) 
  "Parentizes number before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'number 'parentize arg ispec))))

;;;###autoload
(defun brace-number-bfpt (&optional arg ispec) 
  "Braces number before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'number 'brace arg ispec))))

;;;###autoload
(defun bracket-number-bfpt (&optional arg ispec) 
  "Brackets number before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'number 'bracket arg ispec))))

;;;###autoload
(defun kill-number-bfpt ()
  "Kills number before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'number))))

;;;###autoload
(defun mark-number-bfpt ()
  "Marks number before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'number))))

;;;###autoload
(defun backward-number-bfpt (&optional arg ispec) 
  "Moves backward over number before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'number (prefix-numeric-value arg) ispec))

;;;###autoload
(defun float-bfpt (&optional arg ispec) 
  "Returns float before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'float (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-float-bfpt (&optional arg ispec) 
  "Returns border of float before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'float (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun float-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of float before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'float (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun float-bfpt-end-position (&optional arg ispec) 
  "Returns end position of float before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'float (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-float-bfpt (&optional arg ispec) 
  "Returns a copy of float before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'float (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-float-bfpt (&optional arg ispec) 
  "Returns a copy of float before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'float (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-float-bfpt (&optional arg ispec) 
  "Returns a copy of float before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'float (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-float-bfpt (&optional arg ispec) 
  "Doublequotes float before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'float 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-float-bfpt (&optional arg ispec) 
  "Singlequotes float before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'float 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-float-bfpt (&optional arg ispec) 
  "Parentizes float before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'float 'parentize arg ispec))))

;;;###autoload
(defun brace-float-bfpt (&optional arg ispec) 
  "Braces float before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'float 'brace arg ispec))))

;;;###autoload
(defun bracket-float-bfpt (&optional arg ispec) 
  "Brackets float before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'float 'bracket arg ispec))))

;;;###autoload
(defun kill-float-bfpt ()
  "Kills float before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'float))))

;;;###autoload
(defun mark-float-bfpt ()
  "Marks float before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'float))))

;;;###autoload
(defun backward-float-bfpt (&optional arg ispec) 
  "Moves backward over float before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'float (prefix-numeric-value arg) ispec))

;;;###autoload
(defun page-bfpt (&optional arg ispec) 
  "Returns page before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'page (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-page-bfpt (&optional arg ispec) 
  "Returns border of page before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'page (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun page-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of page before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'page (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun page-bfpt-end-position (&optional arg ispec) 
  "Returns end position of page before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'page (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-page-bfpt (&optional arg ispec) 
  "Returns a copy of page before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'page (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-page-bfpt (&optional arg ispec) 
  "Returns a copy of page before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'page (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-page-bfpt (&optional arg ispec) 
  "Returns a copy of page before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'page (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-page-bfpt (&optional arg ispec) 
  "Doublequotes page before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'page 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-page-bfpt (&optional arg ispec) 
  "Singlequotes page before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'page 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-page-bfpt (&optional arg ispec) 
  "Parentizes page before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'page 'parentize arg ispec))))

;;;###autoload
(defun brace-page-bfpt (&optional arg ispec) 
  "Braces page before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'page 'brace arg ispec))))

;;;###autoload
(defun bracket-page-bfpt (&optional arg ispec) 
  "Brackets page before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'page 'bracket arg ispec))))

;;;###autoload
(defun kill-page-bfpt ()
  "Kills page before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'page))))

;;;###autoload
(defun mark-page-bfpt ()
  "Marks page before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'page))))

;;;###autoload
(defun backward-page-bfpt (&optional arg ispec) 
  "Moves backward over page before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'page (prefix-numeric-value arg) ispec))

;;;###autoload
(defun whitespace-bfpt (&optional arg ispec) 
  "Returns whitespace before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'whitespace (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-whitespace-bfpt (&optional arg ispec) 
  "Returns border of whitespace before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'whitespace (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun whitespace-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of whitespace before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'whitespace (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun whitespace-bfpt-end-position (&optional arg ispec) 
  "Returns end position of whitespace before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'whitespace (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-whitespace-bfpt (&optional arg ispec) 
  "Returns a copy of whitespace before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'whitespace (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-whitespace-bfpt (&optional arg ispec) 
  "Returns a copy of whitespace before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'whitespace (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-whitespace-bfpt (&optional arg ispec) 
  "Returns a copy of whitespace before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'whitespace (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-whitespace-bfpt (&optional arg ispec) 
  "Doublequotes whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'whitespace 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-whitespace-bfpt (&optional arg ispec) 
  "Singlequotes whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'whitespace 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-whitespace-bfpt (&optional arg ispec) 
  "Parentizes whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'whitespace 'parentize arg ispec))))

;;;###autoload
(defun brace-whitespace-bfpt (&optional arg ispec) 
  "Braces whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'whitespace 'brace arg ispec))))

;;;###autoload
(defun bracket-whitespace-bfpt (&optional arg ispec) 
  "Brackets whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'whitespace 'bracket arg ispec))))

;;;###autoload
(defun kill-whitespace-bfpt ()
  "Kills whitespace before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'whitespace))))

;;;###autoload
(defun mark-whitespace-bfpt ()
  "Marks whitespace before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'whitespace))))

;;;###autoload
(defun backward-whitespace-bfpt (&optional arg ispec) 
  "Moves backward over whitespace before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'whitespace (prefix-numeric-value arg) ispec))

;;;###autoload
(defun alnum-bfpt (&optional arg ispec) 
  "Returns alnum before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'alnum (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-alnum-bfpt (&optional arg ispec) 
  "Returns border of alnum before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'alnum (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun alnum-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of alnum before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'alnum (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun alnum-bfpt-end-position (&optional arg ispec) 
  "Returns end position of alnum before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'alnum (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-alnum-bfpt (&optional arg ispec) 
  "Returns a copy of alnum before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'alnum (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-alnum-bfpt (&optional arg ispec) 
  "Returns a copy of alnum before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'alnum (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-alnum-bfpt (&optional arg ispec) 
  "Returns a copy of alnum before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'alnum (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-alnum-bfpt (&optional arg ispec) 
  "Doublequotes alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alnum 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-alnum-bfpt (&optional arg ispec) 
  "Singlequotes alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alnum 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-alnum-bfpt (&optional arg ispec) 
  "Parentizes alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alnum 'parentize arg ispec))))

;;;###autoload
(defun brace-alnum-bfpt (&optional arg ispec) 
  "Braces alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alnum 'brace arg ispec))))

;;;###autoload
(defun bracket-alnum-bfpt (&optional arg ispec) 
  "Brackets alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alnum 'bracket arg ispec))))

;;;###autoload
(defun kill-alnum-bfpt ()
  "Kills alnum before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'alnum))))

;;;###autoload
(defun mark-alnum-bfpt ()
  "Marks alnum before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:alnum:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'alnum))))

;;;###autoload
(defun backward-alnum-bfpt (&optional arg ispec) 
  "Moves backward over alnum before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'alnum (prefix-numeric-value arg) ispec))

;;;###autoload
(defun alpha-bfpt (&optional arg ispec) 
  "Returns alpha before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'alpha (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-alpha-bfpt (&optional arg ispec) 
  "Returns border of alpha before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'alpha (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun alpha-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of alpha before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'alpha (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun alpha-bfpt-end-position (&optional arg ispec) 
  "Returns end position of alpha before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'alpha (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-alpha-bfpt (&optional arg ispec) 
  "Returns a copy of alpha before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'alpha (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-alpha-bfpt (&optional arg ispec) 
  "Returns a copy of alpha before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'alpha (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-alpha-bfpt (&optional arg ispec) 
  "Returns a copy of alpha before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'alpha (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-alpha-bfpt (&optional arg ispec) 
  "Doublequotes alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alpha 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-alpha-bfpt (&optional arg ispec) 
  "Singlequotes alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alpha 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-alpha-bfpt (&optional arg ispec) 
  "Parentizes alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alpha 'parentize arg ispec))))

;;;###autoload
(defun brace-alpha-bfpt (&optional arg ispec) 
  "Braces alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alpha 'brace arg ispec))))

;;;###autoload
(defun bracket-alpha-bfpt (&optional arg ispec) 
  "Brackets alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'alpha 'bracket arg ispec))))

;;;###autoload
(defun kill-alpha-bfpt ()
  "Kills alpha before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'alpha))))

;;;###autoload
(defun mark-alpha-bfpt ()
  "Marks alpha before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:alpha:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'alpha))))

;;;###autoload
(defun backward-alpha-bfpt (&optional arg ispec) 
  "Moves backward over alpha before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'alpha (prefix-numeric-value arg) ispec))

;;;###autoload
(defun ascii-bfpt (&optional arg ispec) 
  "Returns ascii before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'ascii (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-ascii-bfpt (&optional arg ispec) 
  "Returns border of ascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'ascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun ascii-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of ascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'ascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun ascii-bfpt-end-position (&optional arg ispec) 
  "Returns end position of ascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'ascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-ascii-bfpt (&optional arg ispec) 
  "Returns a copy of ascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'ascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-ascii-bfpt (&optional arg ispec) 
  "Returns a copy of ascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'ascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-ascii-bfpt (&optional arg ispec) 
  "Returns a copy of ascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'ascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-ascii-bfpt (&optional arg ispec) 
  "Doublequotes ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ascii 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-ascii-bfpt (&optional arg ispec) 
  "Singlequotes ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ascii 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-ascii-bfpt (&optional arg ispec) 
  "Parentizes ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ascii 'parentize arg ispec))))

;;;###autoload
(defun brace-ascii-bfpt (&optional arg ispec) 
  "Braces ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ascii 'brace arg ispec))))

;;;###autoload
(defun bracket-ascii-bfpt (&optional arg ispec) 
  "Brackets ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'ascii 'bracket arg ispec))))

;;;###autoload
(defun kill-ascii-bfpt ()
  "Kills ascii before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'ascii))))

;;;###autoload
(defun mark-ascii-bfpt ()
  "Marks ascii before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:ascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'ascii))))

;;;###autoload
(defun backward-ascii-bfpt (&optional arg ispec) 
  "Moves backward over ascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'ascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun blank-bfpt (&optional arg ispec) 
  "Returns blank before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'blank (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-blank-bfpt (&optional arg ispec) 
  "Returns border of blank before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'blank (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun blank-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of blank before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'blank (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun blank-bfpt-end-position (&optional arg ispec) 
  "Returns end position of blank before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'blank (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-blank-bfpt (&optional arg ispec) 
  "Returns a copy of blank before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'blank (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-blank-bfpt (&optional arg ispec) 
  "Returns a copy of blank before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'blank (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-blank-bfpt (&optional arg ispec) 
  "Returns a copy of blank before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'blank (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-blank-bfpt (&optional arg ispec) 
  "Doublequotes blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'blank 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-blank-bfpt (&optional arg ispec) 
  "Singlequotes blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'blank 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-blank-bfpt (&optional arg ispec) 
  "Parentizes blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'blank 'parentize arg ispec))))

;;;###autoload
(defun brace-blank-bfpt (&optional arg ispec) 
  "Braces blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'blank 'brace arg ispec))))

;;;###autoload
(defun bracket-blank-bfpt (&optional arg ispec) 
  "Brackets blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'blank 'bracket arg ispec))))

;;;###autoload
(defun kill-blank-bfpt ()
  "Kills blank before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'blank))))

;;;###autoload
(defun mark-blank-bfpt ()
  "Marks blank before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:blank:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'blank))))

;;;###autoload
(defun backward-blank-bfpt (&optional arg ispec) 
  "Moves backward over blank before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'blank (prefix-numeric-value arg) ispec))

;;;###autoload
(defun cntrl-bfpt (&optional arg ispec) 
  "Returns cntrl before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'cntrl (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-cntrl-bfpt (&optional arg ispec) 
  "Returns border of cntrl before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'cntrl (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun cntrl-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of cntrl before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'cntrl (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun cntrl-bfpt-end-position (&optional arg ispec) 
  "Returns end position of cntrl before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'cntrl (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-cntrl-bfpt (&optional arg ispec) 
  "Returns a copy of cntrl before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'cntrl (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-cntrl-bfpt (&optional arg ispec) 
  "Returns a copy of cntrl before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'cntrl (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-cntrl-bfpt (&optional arg ispec) 
  "Returns a copy of cntrl before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'cntrl (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-cntrl-bfpt (&optional arg ispec) 
  "Doublequotes cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'cntrl 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-cntrl-bfpt (&optional arg ispec) 
  "Singlequotes cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'cntrl 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-cntrl-bfpt (&optional arg ispec) 
  "Parentizes cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'cntrl 'parentize arg ispec))))

;;;###autoload
(defun brace-cntrl-bfpt (&optional arg ispec) 
  "Braces cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'cntrl 'brace arg ispec))))

;;;###autoload
(defun bracket-cntrl-bfpt (&optional arg ispec) 
  "Brackets cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'cntrl 'bracket arg ispec))))

;;;###autoload
(defun kill-cntrl-bfpt ()
  "Kills cntrl before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'cntrl))))

;;;###autoload
(defun mark-cntrl-bfpt ()
  "Marks cntrl before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:cntrl:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'cntrl))))

;;;###autoload
(defun backward-cntrl-bfpt (&optional arg ispec) 
  "Moves backward over cntrl before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'cntrl (prefix-numeric-value arg) ispec))

;;;###autoload
(defun digit-bfpt (&optional arg ispec) 
  "Returns digit before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'digit (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-digit-bfpt (&optional arg ispec) 
  "Returns border of digit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'digit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun digit-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of digit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'digit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun digit-bfpt-end-position (&optional arg ispec) 
  "Returns end position of digit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'digit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-digit-bfpt (&optional arg ispec) 
  "Returns a copy of digit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'digit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-digit-bfpt (&optional arg ispec) 
  "Returns a copy of digit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'digit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-digit-bfpt (&optional arg ispec) 
  "Returns a copy of digit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'digit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-digit-bfpt (&optional arg ispec) 
  "Doublequotes digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'digit 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-digit-bfpt (&optional arg ispec) 
  "Singlequotes digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'digit 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-digit-bfpt (&optional arg ispec) 
  "Parentizes digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'digit 'parentize arg ispec))))

;;;###autoload
(defun brace-digit-bfpt (&optional arg ispec) 
  "Braces digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'digit 'brace arg ispec))))

;;;###autoload
(defun bracket-digit-bfpt (&optional arg ispec) 
  "Brackets digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'digit 'bracket arg ispec))))

;;;###autoload
(defun kill-digit-bfpt ()
  "Kills digit before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'digit))))

;;;###autoload
(defun mark-digit-bfpt ()
  "Marks digit before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:digit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'digit))))

;;;###autoload
(defun backward-digit-bfpt (&optional arg ispec) 
  "Moves backward over digit before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'digit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun graph-bfpt (&optional arg ispec) 
  "Returns graph before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'graph (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-graph-bfpt (&optional arg ispec) 
  "Returns border of graph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'graph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun graph-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of graph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'graph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun graph-bfpt-end-position (&optional arg ispec) 
  "Returns end position of graph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'graph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-graph-bfpt (&optional arg ispec) 
  "Returns a copy of graph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'graph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-graph-bfpt (&optional arg ispec) 
  "Returns a copy of graph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'graph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-graph-bfpt (&optional arg ispec) 
  "Returns a copy of graph before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'graph (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-graph-bfpt (&optional arg ispec) 
  "Doublequotes graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'graph 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-graph-bfpt (&optional arg ispec) 
  "Singlequotes graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'graph 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-graph-bfpt (&optional arg ispec) 
  "Parentizes graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'graph 'parentize arg ispec))))

;;;###autoload
(defun brace-graph-bfpt (&optional arg ispec) 
  "Braces graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'graph 'brace arg ispec))))

;;;###autoload
(defun bracket-graph-bfpt (&optional arg ispec) 
  "Brackets graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'graph 'bracket arg ispec))))

;;;###autoload
(defun kill-graph-bfpt ()
  "Kills graph before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'graph))))

;;;###autoload
(defun mark-graph-bfpt ()
  "Marks graph before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:graph:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'graph))))

;;;###autoload
(defun backward-graph-bfpt (&optional arg ispec) 
  "Moves backward over graph before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'graph (prefix-numeric-value arg) ispec))

;;;###autoload
(defun lower-bfpt (&optional arg ispec) 
  "Returns lower before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'lower (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-lower-bfpt (&optional arg ispec) 
  "Returns border of lower before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'lower (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun lower-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of lower before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'lower (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun lower-bfpt-end-position (&optional arg ispec) 
  "Returns end position of lower before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'lower (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-lower-bfpt (&optional arg ispec) 
  "Returns a copy of lower before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'lower (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-lower-bfpt (&optional arg ispec) 
  "Returns a copy of lower before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'lower (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-lower-bfpt (&optional arg ispec) 
  "Returns a copy of lower before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'lower (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-lower-bfpt (&optional arg ispec) 
  "Doublequotes lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'lower 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-lower-bfpt (&optional arg ispec) 
  "Singlequotes lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'lower 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-lower-bfpt (&optional arg ispec) 
  "Parentizes lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'lower 'parentize arg ispec))))

;;;###autoload
(defun brace-lower-bfpt (&optional arg ispec) 
  "Braces lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'lower 'brace arg ispec))))

;;;###autoload
(defun bracket-lower-bfpt (&optional arg ispec) 
  "Brackets lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'lower 'bracket arg ispec))))

;;;###autoload
(defun kill-lower-bfpt ()
  "Kills lower before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'lower))))

;;;###autoload
(defun mark-lower-bfpt ()
  "Marks lower before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:lower:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'lower))))

;;;###autoload
(defun backward-lower-bfpt (&optional arg ispec) 
  "Moves backward over lower before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'lower (prefix-numeric-value arg) ispec))

;;;###autoload
(defun multibyte-bfpt (&optional arg ispec) 
  "Returns multibyte before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'multibyte (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-multibyte-bfpt (&optional arg ispec) 
  "Returns border of multibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'multibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun multibyte-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of multibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'multibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun multibyte-bfpt-end-position (&optional arg ispec) 
  "Returns end position of multibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'multibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-multibyte-bfpt (&optional arg ispec) 
  "Returns a copy of multibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'multibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-multibyte-bfpt (&optional arg ispec) 
  "Returns a copy of multibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'multibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-multibyte-bfpt (&optional arg ispec) 
  "Returns a copy of multibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'multibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-multibyte-bfpt (&optional arg ispec) 
  "Doublequotes multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'multibyte 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-multibyte-bfpt (&optional arg ispec) 
  "Singlequotes multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'multibyte 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-multibyte-bfpt (&optional arg ispec) 
  "Parentizes multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'multibyte 'parentize arg ispec))))

;;;###autoload
(defun brace-multibyte-bfpt (&optional arg ispec) 
  "Braces multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'multibyte 'brace arg ispec))))

;;;###autoload
(defun bracket-multibyte-bfpt (&optional arg ispec) 
  "Brackets multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'multibyte 'bracket arg ispec))))

;;;###autoload
(defun kill-multibyte-bfpt ()
  "Kills multibyte before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'multibyte))))

;;;###autoload
(defun mark-multibyte-bfpt ()
  "Marks multibyte before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:multibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'multibyte))))

;;;###autoload
(defun backward-multibyte-bfpt (&optional arg ispec) 
  "Moves backward over multibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'multibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun nonascii-bfpt (&optional arg ispec) 
  "Returns nonascii before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'nonascii (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-nonascii-bfpt (&optional arg ispec) 
  "Returns border of nonascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'nonascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun nonascii-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of nonascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'nonascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun nonascii-bfpt-end-position (&optional arg ispec) 
  "Returns end position of nonascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'nonascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-nonascii-bfpt (&optional arg ispec) 
  "Returns a copy of nonascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'nonascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-nonascii-bfpt (&optional arg ispec) 
  "Returns a copy of nonascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'nonascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-nonascii-bfpt (&optional arg ispec) 
  "Returns a copy of nonascii before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'nonascii (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-nonascii-bfpt (&optional arg ispec) 
  "Doublequotes nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'nonascii 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-nonascii-bfpt (&optional arg ispec) 
  "Singlequotes nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'nonascii 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-nonascii-bfpt (&optional arg ispec) 
  "Parentizes nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'nonascii 'parentize arg ispec))))

;;;###autoload
(defun brace-nonascii-bfpt (&optional arg ispec) 
  "Braces nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'nonascii 'brace arg ispec))))

;;;###autoload
(defun bracket-nonascii-bfpt (&optional arg ispec) 
  "Brackets nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'nonascii 'bracket arg ispec))))

;;;###autoload
(defun kill-nonascii-bfpt ()
  "Kills nonascii before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'nonascii))))

;;;###autoload
(defun mark-nonascii-bfpt ()
  "Marks nonascii before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:nonascii:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'nonascii))))

;;;###autoload
(defun backward-nonascii-bfpt (&optional arg ispec) 
  "Moves backward over nonascii before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'nonascii (prefix-numeric-value arg) ispec))

;;;###autoload
(defun print-bfpt (&optional arg ispec) 
  "Returns print before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'print (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-print-bfpt (&optional arg ispec) 
  "Returns border of print before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'print (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun print-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of print before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'print (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun print-bfpt-end-position (&optional arg ispec) 
  "Returns end position of print before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'print (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-print-bfpt (&optional arg ispec) 
  "Returns a copy of print before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'print (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-print-bfpt (&optional arg ispec) 
  "Returns a copy of print before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'print (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-print-bfpt (&optional arg ispec) 
  "Returns a copy of print before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'print (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-print-bfpt (&optional arg ispec) 
  "Doublequotes print before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'print 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-print-bfpt (&optional arg ispec) 
  "Singlequotes print before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'print 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-print-bfpt (&optional arg ispec) 
  "Parentizes print before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'print 'parentize arg ispec))))

;;;###autoload
(defun brace-print-bfpt (&optional arg ispec) 
  "Braces print before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'print 'brace arg ispec))))

;;;###autoload
(defun bracket-print-bfpt (&optional arg ispec) 
  "Brackets print before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'print 'bracket arg ispec))))

;;;###autoload
(defun kill-print-bfpt ()
  "Kills print before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'print))))

;;;###autoload
(defun mark-print-bfpt ()
  "Marks print before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:print:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'print))))

;;;###autoload
(defun backward-print-bfpt (&optional arg ispec) 
  "Moves backward over print before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'print (prefix-numeric-value arg) ispec))

;;;###autoload
(defun punct-bfpt (&optional arg ispec) 
  "Returns punct before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'punct (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-punct-bfpt (&optional arg ispec) 
  "Returns border of punct before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'punct (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun punct-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of punct before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'punct (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun punct-bfpt-end-position (&optional arg ispec) 
  "Returns end position of punct before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'punct (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-punct-bfpt (&optional arg ispec) 
  "Returns a copy of punct before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'punct (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-punct-bfpt (&optional arg ispec) 
  "Returns a copy of punct before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'punct (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-punct-bfpt (&optional arg ispec) 
  "Returns a copy of punct before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'punct (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-punct-bfpt (&optional arg ispec) 
  "Doublequotes punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'punct 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-punct-bfpt (&optional arg ispec) 
  "Singlequotes punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'punct 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-punct-bfpt (&optional arg ispec) 
  "Parentizes punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'punct 'parentize arg ispec))))

;;;###autoload
(defun brace-punct-bfpt (&optional arg ispec) 
  "Braces punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'punct 'brace arg ispec))))

;;;###autoload
(defun bracket-punct-bfpt (&optional arg ispec) 
  "Brackets punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'punct 'bracket arg ispec))))

;;;###autoload
(defun kill-punct-bfpt ()
  "Kills punct before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'punct))))

;;;###autoload
(defun mark-punct-bfpt ()
  "Marks punct before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:punct:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'punct))))

;;;###autoload
(defun backward-punct-bfpt (&optional arg ispec) 
  "Moves backward over punct before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'punct (prefix-numeric-value arg) ispec))

;;;###autoload
(defun space-bfpt (&optional arg ispec) 
  "Returns space before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'space (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-space-bfpt (&optional arg ispec) 
  "Returns border of space before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'space (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun space-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of space before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'space (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun space-bfpt-end-position (&optional arg ispec) 
  "Returns end position of space before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'space (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-space-bfpt (&optional arg ispec) 
  "Returns a copy of space before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'space (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-space-bfpt (&optional arg ispec) 
  "Returns a copy of space before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'space (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-space-bfpt (&optional arg ispec) 
  "Returns a copy of space before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'space (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-space-bfpt (&optional arg ispec) 
  "Doublequotes space before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'space 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-space-bfpt (&optional arg ispec) 
  "Singlequotes space before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'space 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-space-bfpt (&optional arg ispec) 
  "Parentizes space before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'space 'parentize arg ispec))))

;;;###autoload
(defun brace-space-bfpt (&optional arg ispec) 
  "Braces space before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'space 'brace arg ispec))))

;;;###autoload
(defun bracket-space-bfpt (&optional arg ispec) 
  "Brackets space before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'space 'bracket arg ispec))))

;;;###autoload
(defun kill-space-bfpt ()
  "Kills space before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'space))))

;;;###autoload
(defun mark-space-bfpt ()
  "Marks space before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:space:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'space))))

;;;###autoload
(defun backward-space-bfpt (&optional arg ispec) 
  "Moves backward over space before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'space (prefix-numeric-value arg) ispec))

;;;###autoload
(defun unibyte-bfpt (&optional arg ispec) 
  "Returns unibyte before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'unibyte (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-unibyte-bfpt (&optional arg ispec) 
  "Returns border of unibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'unibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun unibyte-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of unibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'unibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun unibyte-bfpt-end-position (&optional arg ispec) 
  "Returns end position of unibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'unibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-unibyte-bfpt (&optional arg ispec) 
  "Returns a copy of unibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'unibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-unibyte-bfpt (&optional arg ispec) 
  "Returns a copy of unibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'unibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-unibyte-bfpt (&optional arg ispec) 
  "Returns a copy of unibyte before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'unibyte (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-unibyte-bfpt (&optional arg ispec) 
  "Doublequotes unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'unibyte 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-unibyte-bfpt (&optional arg ispec) 
  "Singlequotes unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'unibyte 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-unibyte-bfpt (&optional arg ispec) 
  "Parentizes unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'unibyte 'parentize arg ispec))))

;;;###autoload
(defun brace-unibyte-bfpt (&optional arg ispec) 
  "Braces unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'unibyte 'brace arg ispec))))

;;;###autoload
(defun bracket-unibyte-bfpt (&optional arg ispec) 
  "Brackets unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'unibyte 'bracket arg ispec))))

;;;###autoload
(defun kill-unibyte-bfpt ()
  "Kills unibyte before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'unibyte))))

;;;###autoload
(defun mark-unibyte-bfpt ()
  "Marks unibyte before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:unibyte:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'unibyte))))

;;;###autoload
(defun backward-unibyte-bfpt (&optional arg ispec) 
  "Moves backward over unibyte before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'unibyte (prefix-numeric-value arg) ispec))

;;;###autoload
(defun upper-bfpt (&optional arg ispec) 
  "Returns upper before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'upper (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-upper-bfpt (&optional arg ispec) 
  "Returns border of upper before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'upper (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun upper-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of upper before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'upper (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun upper-bfpt-end-position (&optional arg ispec) 
  "Returns end position of upper before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'upper (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-upper-bfpt (&optional arg ispec) 
  "Returns a copy of upper before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'upper (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-upper-bfpt (&optional arg ispec) 
  "Returns a copy of upper before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'upper (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-upper-bfpt (&optional arg ispec) 
  "Returns a copy of upper before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'upper (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-upper-bfpt (&optional arg ispec) 
  "Doublequotes upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'upper 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-upper-bfpt (&optional arg ispec) 
  "Singlequotes upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'upper 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-upper-bfpt (&optional arg ispec) 
  "Parentizes upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'upper 'parentize arg ispec))))

;;;###autoload
(defun brace-upper-bfpt (&optional arg ispec) 
  "Braces upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'upper 'brace arg ispec))))

;;;###autoload
(defun bracket-upper-bfpt (&optional arg ispec) 
  "Brackets upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'upper 'bracket arg ispec))))

;;;###autoload
(defun kill-upper-bfpt ()
  "Kills upper before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'upper))))

;;;###autoload
(defun mark-upper-bfpt ()
  "Marks upper before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:upper:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'upper))))

;;;###autoload
(defun backward-upper-bfpt (&optional arg ispec) 
  "Moves backward over upper before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'upper (prefix-numeric-value arg) ispec))

;;;###autoload
(defun xdigit-bfpt (&optional arg ispec) 
  "Returns xdigit before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'xdigit (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-xdigit-bfpt (&optional arg ispec) 
  "Returns border of xdigit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'xdigit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun xdigit-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of xdigit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'xdigit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun xdigit-bfpt-end-position (&optional arg ispec) 
  "Returns end position of xdigit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'xdigit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-xdigit-bfpt (&optional arg ispec) 
  "Returns a copy of xdigit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'xdigit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-xdigit-bfpt (&optional arg ispec) 
  "Returns a copy of xdigit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'xdigit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-xdigit-bfpt (&optional arg ispec) 
  "Returns a copy of xdigit before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'xdigit (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-xdigit-bfpt (&optional arg ispec) 
  "Doublequotes xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'xdigit 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-xdigit-bfpt (&optional arg ispec) 
  "Singlequotes xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'xdigit 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-xdigit-bfpt (&optional arg ispec) 
  "Parentizes xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'xdigit 'parentize arg ispec))))

;;;###autoload
(defun brace-xdigit-bfpt (&optional arg ispec) 
  "Braces xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'xdigit 'brace arg ispec))))

;;;###autoload
(defun bracket-xdigit-bfpt (&optional arg ispec) 
  "Brackets xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'xdigit 'bracket arg ispec))))

;;;###autoload
(defun kill-xdigit-bfpt ()
  "Kills xdigit before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'xdigit))))

;;;###autoload
(defun mark-xdigit-bfpt ()
  "Marks xdigit before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward "^[:xdigit:]")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'xdigit))))

;;;###autoload
(defun backward-xdigit-bfpt (&optional arg ispec) 
  "Moves backward over xdigit before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'xdigit (prefix-numeric-value arg) ispec))

;;;###autoload
(defun region-bfpt (&optional arg ispec) 
  "Returns region before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'region (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-region-bfpt (&optional arg ispec) 
  "Returns border of region before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'region (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun region-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of region before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'region (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun region-bfpt-end-position (&optional arg ispec) 
  "Returns end position of region before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'region (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-region-bfpt (&optional arg ispec) 
  "Returns a copy of region before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'region (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-region-bfpt (&optional arg ispec) 
  "Returns a copy of region before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'region (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-region-bfpt (&optional arg ispec) 
  "Returns a copy of region before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'region (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-region-bfpt (&optional arg ispec) 
  "Doublequotes region before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'region 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-region-bfpt (&optional arg ispec) 
  "Singlequotes region before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'region 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-region-bfpt (&optional arg ispec) 
  "Parentizes region before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'region 'parentize arg ispec))))

;;;###autoload
(defun brace-region-bfpt (&optional arg ispec) 
  "Braces region before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'region 'brace arg ispec))))

;;;###autoload
(defun bracket-region-bfpt (&optional arg ispec) 
  "Brackets region before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'region 'bracket arg ispec))))

;;;###autoload
(defun kill-region-bfpt ()
  "Kills region before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'region))))

;;;###autoload
(defun mark-region-bfpt ()
  "Marks region before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'region))))

;;;###autoload
(defun backward-region-bfpt (&optional arg ispec) 
  "Moves backward over region before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'region (prefix-numeric-value arg) ispec))

;;;###autoload
(defun delimited-bfpt (&optional arg ispec) 
  "Returns delimited before point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'delimited (prefix-numeric-value arg) ispec)))

;;;###autoload
(defun bounds-of-delimited-bfpt (&optional arg ispec) 
  "Returns border of delimited before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-bounds 'delimited (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun delimited-bfpt-beginning-position (&optional arg ispec) 
  "Returns beginning of delimited before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-beginning 'delimited (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun delimited-bfpt-end-position (&optional arg ispec) 
  "Returns end position of delimited before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-end 'delimited (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun copy-delimited-bfpt (&optional arg ispec) 
  "Returns a copy of delimited before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-copy 'delimited (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun separate-delimited-bfpt (&optional arg ispec) 
  "Returns a copy of delimited before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-separate 'delimited (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun comment-delimited-bfpt (&optional arg ispec) 
  "Returns a copy of delimited before point if any, nil otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-comment 'delimited (prefix-numeric-value arg) ispec))))

;;;###autoload
(defun doublequote-delimited-bfpt (&optional arg ispec) 
  "Doublequotes delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'delimited 'doublequote arg ispec))))

;;;###autoload
(defun singlequote-delimited-bfpt (&optional arg ispec) 
  "Singlequotes delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'delimited 'singlequote arg ispec))))

;;;###autoload
(defun parenthese-delimited-bfpt (&optional arg ispec) 
  "Parentizes delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'delimited 'parentize arg ispec))))

;;;###autoload
(defun brace-delimited-bfpt (&optional arg ispec) 
  "Braces delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'delimited 'brace arg ispec))))

;;;###autoload
(defun bracket-delimited-bfpt (&optional arg ispec) 
  "Brackets delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-delim 'delimited 'bracket arg ispec))))

;;;###autoload
(defun kill-delimited-bfpt ()
  "Kills delimited before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-kill 'delimited))))

;;;###autoload
(defun mark-delimited-bfpt ()
  "Marks delimited before point if any, does nothing otherwise "
  (interactive "*")
  (save-excursion 
    (skip-chars-backward " \t\n\r\f")
    (unless (bobp)
      (forward-char -1)
      (thatpt-mark 'delimited))))

;;;###autoload
(defun backward-delimited-bfpt (&optional arg ispec) 
  "Moves backward over delimited before point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-backward 'delimited (prefix-numeric-value arg) ispec))



;;; thing-before-point-utils.el ends here
(provide 'thing-before-point-utils)
